<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database

if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];
    
    // Fetch the customer details from company_info table
    $stmt = $pdo->prepare('SELECT * FROM company_info WHERE debtor_code = :debtor_code');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->execute();
    $customer = $stmt->fetch(PDO::FETCH_ASSOC);
    
    // Check if customer exists
    if (!$customer) {
        echo "<p>Customer not found.</p>";
        exit();
    }

    // Fetch related companies from relation_company table
    $relatedCompaniesStmt = $pdo->prepare('SELECT ci.company_name, ci.debtor_code 
                                           FROM relation_company rc 
                                           JOIN company_info ci ON rc.related_company_debtor_code = ci.debtor_code 
                                           WHERE rc.debtor_code = :debtor_code');
    $relatedCompaniesStmt->bindParam(':debtor_code', $debtorCode);
    $relatedCompaniesStmt->execute();
    $relatedCompanies = $relatedCompaniesStmt->fetchAll(PDO::FETCH_ASSOC);

    // Fetch all companies for dropdown
    $companies = $pdo->query('SELECT debtor_code, company_name FROM company_info')->fetchAll(PDO::FETCH_ASSOC);

    // Fetch dealer companies to display in the new dropdown
    $dealerCompanies = $pdo->query('SELECT debtor_code, company_name FROM company_info WHERE is_dealer = 1')->fetchAll(PDO::FETCH_ASSOC);
} else {
    echo "<p>No Debtor Code provided.</p>";
    require 'layout/footer.php';
    exit();
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Fetch the old data before updating
    $oldDataStmt = $pdo->prepare('SELECT * FROM company_info WHERE debtor_code = :debtor_code');
    $oldDataStmt->bindParam(':debtor_code', $debtorCode);
    $oldDataStmt->execute();
    $oldData = $oldDataStmt->fetch(PDO::FETCH_ASSOC);

    // Collect and sanitize input
    $newData = [
        'company_name' => $_POST['company_name'] ?? '',
        'email' => $_POST['email'] ?? '',
        'address1' => $_POST['address1'] ?? '',
        'address2' => $_POST['address2'] ?? '',
        'address3' => $_POST['address3'] ?? '',
        'address4' => $_POST['address4'] ?? '',
        'postcode' => $_POST['postcode'] ?? '',
        'phone1' => $_POST['phone1'] ?? '',
        'phone2' => $_POST['phone2'] ?? '',
        'fax' => $_POST['fax'] ?? '',
        'mobile' => $_POST['mobile'] ?? '',
        'attention' => $_POST['attention'] ?? '',
        'introducer_person' => $_POST['introducer_person'] ?? '',
        'business_registration_number' => $_POST['business_registration_number'] ?? '',
        'tin_number' => $_POST['tin_number'] ?? '',
        'service_tax_number' => $_POST['service_tax_number'] ?? '',
        'sales_tax_number' => $_POST['sales_tax_number'] ?? '',
        'gst_number' => $_POST['gst_number'] ?? '',
        'is_dealer' => isset($_POST['is_dealer']) ? 1 : 0,
        'billing_company' => $_POST['billing_company'] ?? ''
    ];

    // Dynamically concatenate addresses with commas only if the next field has data
    $addressParts = [];
    if (!empty($newData['address1'])) $addressParts[] = $newData['address1'];
    if (!empty($newData['address2'])) $addressParts[] = $newData['address2'];
    if (!empty($newData['address3'])) $addressParts[] = $newData['address3'];
    if (!empty($newData['address4'])) $addressParts[] = $newData['address4'];
    $newData['full_address'] = implode(', ', $addressParts); // Join with commas

    // Compare old and new data to identify changes
    $changes = [];
    foreach ($newData as $key => $value) {
        if ($oldData[$key] != $value) {
            $changes[$key] = [
                'old' => $oldData[$key],
                'new' => $value
            ];
        }
    }

    // If there are changes, proceed with the update and log the changes
    if (!empty($changes)) {
        try {
            // Begin transaction
            $pdo->beginTransaction();

            // Prepare and execute update into the company_info table
            $stmt = $pdo->prepare('UPDATE company_info SET 
                company_name = :company_name, 
                email = :email, 
                address1 = :address1, 
                address2 = :address2, 
                address3 = :address3, 
                address4 = :address4, 
                full_address = :full_address, 
                postcode = :postcode, 
                phone1 = :phone1, 
                phone2 = :phone2, 
                fax = :fax, 
                mobile = :mobile, 
                attention = :attention, 
                introducer_person = :introducer_person, 
                business_registration_number = :business_registration_number, 
                tin_number = :tin_number, 
                service_tax_number = :service_tax_number, 
                sales_tax_number = :sales_tax_number, 
                gst_number = :gst_number, 
                is_dealer = :is_dealer,
                billing_company = :billing_company
                WHERE debtor_code = :debtor_code');
            
            // Bind parameters
            foreach ($newData as $key => $value) {
                $stmt->bindValue(':' . $key, $value);
            }
            $stmt->bindParam(':debtor_code', $debtorCode);

            // Execute and check for success
            if ($stmt->execute()) {
                // Delete existing related companies
                $deleteRelatedStmt = $pdo->prepare('DELETE FROM relation_company WHERE debtor_code = :debtor_code');
                $deleteRelatedStmt->bindParam(':debtor_code', $debtorCode);
                $deleteRelatedStmt->execute();

                // Insert new related companies
                $related_companies = $_POST['related_companies'] ?? [];
                $relationStmt = $pdo->prepare('INSERT INTO relation_company (debtor_code, related_company_debtor_code) VALUES (:debtor_code, :related_company_debtor_code)');
                foreach ($related_companies as $related_company_debtor_code) {
                    $relationStmt->bindParam(':debtor_code', $debtorCode);
                    $relationStmt->bindParam(':related_company_debtor_code', $related_company_debtor_code);
                    $relationStmt->execute();
                }

                // Commit the transaction
                $pdo->commit();

                // Log the changes
                $logMessage = "Company updated: Debtor Code - $debtorCode. Changes: ";
                foreach ($changes as $field => $change) {
                    $logMessage .= "$field (old: {$change['old']}, new: {$change['new']}), ";
                }
                $logMessage = rtrim($logMessage, ', '); // Remove trailing comma

                $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                           VALUES (:username, :timestamp, :role, :activity)";
                $stmtLog = $pdo->prepare($sqlLog);
                $stmtLog->execute([
                    ':username' => $_SESSION['username'],
                    ':timestamp' => date('Y-m-d H:i:s'),
                    ':role' => $_SESSION['role'],
                    ':activity' => $logMessage
                ]);

                // Show success alert and redirect
                echo "<script>alert('Company information updated successfully.'); window.location.href = 'company_details.php?debtor_code=$debtorCode&company_name=" . urlencode($newData['company_name']) . "';</script>";
                exit();
            } else {
                echo "<script>alert('Failed to update data. Please try again.');</script>";
            }
        } catch (PDOException $e) {
            $pdo->rollBack(); // Roll back transaction in case of error
            $error = 'Database error: ' . $e->getMessage(); // Capture any error messages
            echo "<script>alert('Database error: " . $error . "');</script>";
        }
    } else {
        // No changes detected, show alert and redirect back to company_details.php
        echo "<script>alert('No changes made.'); window.location.href = 'company_details.php?debtor_code=$debtorCode';</script>";
        exit();
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Company Information</title>
    <!-- Include Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Include Bootstrap Select CSS -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-select/1.14.0-beta2/css/bootstrap-select.min.css">
</head>
<body>
    <div class="container my-5">
        <div class="card">
            <div class="card-header">
                <h1 class="mb-0">Edit Company Information</h1>
            </div>
            <div class="card-body">
                <form method="post" action="">
                    <!-- Company Details Section -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Company Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="company_name" name="company_name" class="form-control" placeholder="Company Name" value="<?= htmlspecialchars($customer['company_name']); ?>">
                                        <label for="company_name">Company Name</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="email" id="email" name="email" class="form-control" placeholder="Email" value="<?= htmlspecialchars($customer['email']); ?>">
                                        <label for="email">Email</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Address Information Section -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Address Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="address1" name="address1" class="form-control" placeholder="Address 1" value="<?= htmlspecialchars($customer['address1']); ?>">
                                        <label for="address1">Address 1</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="address2" name="address2" class="form-control" placeholder="Address 2" value="<?= htmlspecialchars($customer['address2']); ?>">
                                        <label for="address2">Address 2</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="address3" name="address3" class="form-control" placeholder="Address 3" value="<?= htmlspecialchars($customer['address3']); ?>">
                                        <label for="address3">Address 3</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="address4" name="address4" class="form-control" placeholder="Address 4" value="<?= htmlspecialchars($customer['address4']); ?>">
                                        <label for="address4">Address 4</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="postcode" name="postcode" class="form-control" placeholder="Postcode" value="<?= htmlspecialchars($customer['postcode']); ?>">
                                        <label for="postcode">Postcode</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Contact Information Section -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Contact Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="phone1" name="phone1" class="form-control" placeholder="Phone 1" value="<?= htmlspecialchars($customer['phone1']); ?>">
                                        <label for="phone1">Phone 1</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="phone2" name="phone2" class="form-control" placeholder="Phone 2" value="<?= htmlspecialchars($customer['phone2']); ?>">
                                        <label for="phone2">Phone 2</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="fax" name="fax" class="form-control" placeholder="Fax" value="<?= htmlspecialchars($customer['fax']); ?>">
                                        <label for="fax">Fax</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="mobile" name="mobile" class="form-control" placeholder="Mobile" value="<?= htmlspecialchars($customer['mobile']); ?>">
                                        <label for="mobile">Mobile</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="attention" name="attention" class="form-control" placeholder="Attention" value="<?= htmlspecialchars($customer['attention']); ?>">
                                        <label for="attention">Attention</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="introducer_person" name="introducer_person" class="form-control" placeholder="Introducer Person" value="<?= htmlspecialchars($customer['introducer_person']); ?>">
                                        <label for="introducer_person">Introducer Person</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Registration and Tax Information Section -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Registration and Tax Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="business_registration_number" name="business_registration_number" class="form-control" placeholder="Business Registration Number" value="<?= htmlspecialchars($customer['business_registration_number']); ?>">
                                        <label for="business_registration_number">Business Registration Number</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="tin_number" name="tin_number" class="form-control" placeholder="Tin Number" value="<?= htmlspecialchars($customer['tin_number']); ?>">
                                        <label for="tin_number">Tin Number</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="service_tax_number" name="service_tax_number" class="form-control" placeholder="Service Tax Number" value="<?= htmlspecialchars($customer['service_tax_number']); ?>">
                                        <label for="service_tax_number">Service Tax Number</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="sales_tax_number" name="sales_tax_number" class="form-control" placeholder="Sales Tax Number" value="<?= htmlspecialchars($customer['sales_tax_number']); ?>">
                                        <label for="sales_tax_number">Sales Tax Number</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" id="gst_number" name="gst_number" class="form-control" placeholder="GST Number" value="<?= htmlspecialchars($customer['gst_number']); ?>">
                                        <label for="gst_number">GST Number</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Additional Information Section -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Additional Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row mb-3">
                                <div class="col-md-12">
                                    <div class="form-check">
                                        <input type="checkbox" class="form-check-input" id="is_dealer" name="is_dealer" <?= $customer['is_dealer'] == 1 ? 'checked' : ''; ?>>
                                        <label class="form-check-label" for="is_dealer">Is Dealer</label>
                                    </div>
                                </div>
                            </div>

                            <div class="row mb-3">
                                <div class="col-md-12">
                                    <label for="related_companies" class="form-label">Related Companies (Select Multiple):</label>
                                    <select id="related_companies" name="related_companies[]" class="selectpicker form-select" multiple data-live-search="true">
                                        <?php foreach ($companies as $company): ?>
                                            <option value="<?php echo $company['debtor_code']; ?>" <?php echo in_array($company['debtor_code'], array_column($relatedCompanies, 'debtor_code')) ? 'selected' : ''; ?>>
                                                <?php echo $company['company_name'] . ' (Debtor Code: ' . $company['debtor_code'] . ')'; ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>

                            <div class="row mb-3">
                                <div class="col-md-12">
                                    <div class="form-check">
                                        <input type="checkbox" class="form-check-input" id="billing_company_checkbox" name="billing_company_checkbox" <?= !empty($customer['billing_company']) ? 'checked' : ''; ?>>
                                        <label class="form-check-label" for="billing_company_checkbox">Billing Company</label>
                                    </div>
                                    <select id="dealer_companies" name="billing_company" class="form-select" style="display: none;">
                                        <option value="">Select a Billing Company</option>
                                        <?php foreach ($dealerCompanies as $dealerCompany): ?>
                                            <option value="<?php echo $dealerCompany['debtor_code']; ?>" <?php echo $dealerCompany['debtor_code'] == $customer['billing_company'] ? 'selected' : ''; ?>>
                                                <?php echo $dealerCompany['company_name'] . ' (Debtor Code: ' . $dealerCompany['debtor_code'] . ')'; ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Submit and Back Buttons -->
                    <div class="d-flex justify-content-between">
                        <a href="company_details.php?debtor_code=<?= $customer['debtor_code']; ?>&company_name=<?= urlencode($customer['company_name']); ?>" class="btn btn-secondary">Back</a>
                        <button type="submit" class="btn btn-primary">Update Company</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Include Bootstrap JS and dependencies -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <!-- Include Bootstrap Select JS -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-select/1.14.0-beta2/js/bootstrap-select.min.js"></script>
    <script>
        $(document).ready(function() {
            $('.selectpicker').selectpicker(); // Initialize selectpicker

            // Function to handle checkbox interactions
            function handleCheckboxInteractions() {
                const billingCompanyCheckbox = $('#billing_company_checkbox');
                const dealerCompaniesDropdown = $('#dealer_companies');
                const isDealerCheckbox = $('#is_dealer');

                if (billingCompanyCheckbox.is(':checked')) {
                    dealerCompaniesDropdown.show();
                    isDealerCheckbox.prop('disabled', true);
                } else {
                    dealerCompaniesDropdown.hide();
                    isDealerCheckbox.prop('disabled', false);
                }

                if (isDealerCheckbox.is(':checked')) {
                    billingCompanyCheckbox.prop('disabled', true);
                } else {
                    billingCompanyCheckbox.prop('disabled', false);
                }
            }

            // Initial call to set the initial state
            handleCheckboxInteractions();

            // Event listeners for checkbox changes
            $('#billing_company_checkbox').change(function() {
                handleCheckboxInteractions();
            });

            $('#is_dealer').change(function() {
                handleCheckboxInteractions();
            });
        });
    </script>
</body>
</html>