<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password decryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_ac_client_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_ac_client_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeClientId = $_GET['item_type_ac_client_id'];

    // Fetch the item details based on debtor_code and item_type_ac_client_id
    $stmt = $pdo->prepare('SELECT * FROM item_type_ac_client WHERE debtor_code = :debtor_code AND item_type_ac_client_id = :item_type_ac_client_id LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_type_ac_client_id', $itemTypeClientId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($item) {
        // Fetch company_name directly from the fetched item
        $companyName = $item['company_name'];

        // Fetch installed PC options from item_type_pc where debtor_code and company_name match
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtorCode AND company_name = :companyName");
        $stmt->execute([':debtorCode' => $debtorCode, ':companyName' => $companyName]);
        $installedPcOptions = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } else {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}

// Handle form submission to update data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate input data
    $active = isset($_POST['active']) ? 1 : 0;
    $autocountClientVersion = $_POST['autocount_client_version'] ?? '';
    $installedPc = $_POST['installed_pc'] ?? '';
    $others = $_POST['others'] ?? '';

    if (empty($autocountClientVersion) || empty($installedPc)) {
        echo "<script>alert('AutoCount Client Version and Installed PC are required.');</script>";
        exit;
    }

    // Compare old and new values
    $logMessage = "Changes made to Autocount client for company: $companyName\n";
    $changes = [];

    if ($item['active'] != $active) {
        $changes['active'] = $item['active'] . " -> " . $active;
    }
    if ($item['autocount_client_version'] != $autocountClientVersion) {
        $changes['autocount_client_version'] = $item['autocount_client_version'] . " -> " . $autocountClientVersion;
    }
    if ($item['installed_pc'] != $installedPc) {
        $changes['installed_pc'] = $item['installed_pc'] . " -> " . $installedPc;
    }
    if ($item['others'] != $others) {
        $changes['others'] = $item['others'] . " -> " . $others;
    }

    // If there are changes, log them
    if (!empty($changes)) {
        foreach ($changes as $field => $change) {
            $logMessage .= "$field: $change\n";
        }

        try {
            // Update the new table `item_type_ac_client`
            $stmt = $pdo->prepare("UPDATE item_type_ac_client SET
                active = :active,
                autocount_client_version = :autocount_client_version,
                installed_pc = :installed_pc,
                others = :others,
                updated_time = NOW()
                WHERE debtor_code = :debtor_code AND item_type_ac_client_id = :item_type_ac_client_id");

            $stmt->execute([
                ':active' => $active,
                ':autocount_client_version' => $autocountClientVersion,
                ':installed_pc' => $installedPc,
                ':others' => $others,
                ':debtor_code' => $debtorCode,
                ':item_type_ac_client_id' => $itemTypeClientId
            ]);

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // Success alert and redirect
            echo "<script>alert('Data updated successfully!'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=$debtorCode';</script>";
        } catch (PDOException $e) {
            // Display the database error for debugging
            error_log('Database update error: ' . $e->getMessage());
            echo "<script>alert('Failed to update data. Error: " . addslashes($e->getMessage()) . "');</script>";
        }
    } else {
        // No changes were made, show alert and redirect
        echo "<script>alert('No changes were made.'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=$debtorCode';</script>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Autocount/Payroll Client Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Autocount/Payroll Client Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display Information Section -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($item['item_type_name']); ?></strong></p>
                    <p>Item Type Ac Group: <strong><?php echo htmlspecialchars($item['item_type_ac_group_name']); ?></strong></p>
                </div>

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $item['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Edit Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Edit Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-control" id="autocount_client_version" name="autocount_client_version">
                                        <option value="" disabled>Please select a version</option>
                                        <option value="AutoCount Accounting Client" <?php echo $item['autocount_client_version'] == 'AutoCount Accounting Client' ? 'selected' : ''; ?>>AutoCount Accounting Client</option>
                                        <option value="AutoCount POS A" <?php echo $item['autocount_client_version'] == 'AutoCount POS A' ? 'selected' : ''; ?>>AutoCount POS A</option>
                                        <option value="AutoCount POS B" <?php echo $item['autocount_client_version'] == 'AutoCount POS B' ? 'selected' : ''; ?>>AutoCount POS B</option>
                                        <option value="AutoCount POS Branch" <?php echo $item['autocount_client_version'] == 'AutoCount POS Branch' ? 'selected' : ''; ?>>AutoCount POS Branch</option>
                                        <option value="Million Payroll Client" <?php echo $item['autocount_client_version'] == 'Million Payroll Client' ? 'selected' : ''; ?>>Million Payroll Client</option>
                                        <option value="Million Accounting Client" <?php echo $item['autocount_client_version'] == 'Million Accounting Client' ? 'selected' : ''; ?>>Million Accounting Client</option>
                                    </select>
                                    <label for="autocount_client_version">AutoCount Client Version</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-control" id="installed_pc" name="installed_pc">
                                        <option value="" disabled>Please select a PC</option>
                                        <?php foreach ($installedPcOptions as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>" <?php echo $item['installed_pc'] == $option ? 'selected' : ''; ?>><?php echo htmlspecialchars($option); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="installed_pc">Installed PC</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-floating">
                                    <textarea class="form-control" id="others" name="others" placeholder="Enter other information"><?php echo htmlspecialchars($item['others']); ?></textarea>
                                    <label for="others">Others:</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Update</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

