<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_hosting_domain_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_hosting_domain_id'])) {
    echo "<p>No debtor code or hosting domain ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$hostingDomainId = $_GET['item_type_hosting_domain_id'];

// Fetch the hosting domain details based on debtor_code and item_type_hosting_domain_id
$stmt = $pdo->prepare('SELECT * FROM item_type_hosting_domain WHERE debtor_code = :debtor_code AND item_type_hosting_domain_id = :item_type_hosting_domain_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_hosting_domain_id' => $hostingDomainId]);
$hostingDomain = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$hostingDomain) {
    echo "<p>No hosting domain found with the provided ID.</p>";
    exit;
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $domain_name = htmlspecialchars($_POST['domain_name']);
    $server_names = array_filter($_POST['server_name'] ?? [], function($server_name) {
        return !empty(trim($server_name));
    }); // Filter out empty server names
    $register_on = htmlspecialchars($_POST['register_on']);
    $service_provider = htmlspecialchars($_POST['service_provider']);
    $others = htmlspecialchars($_POST['others']);

    // Convert server names array to comma-separated string
    $server_names_string = implode(", ", $server_names);

    // Store the old data for logging
    $oldData = $hostingDomain;

    // Check if any changes were made
    $hasChanges = false;
    if ($active != $oldData['active']) $hasChanges = true;
    if ($domain_name != $oldData['domain_name']) $hasChanges = true;
    if ($server_names_string != $oldData['server_name']) $hasChanges = true;
    if ($register_on != $oldData['register_on']) $hasChanges = true;
    if ($service_provider != $oldData['service_provider']) $hasChanges = true;
    if ($others != $oldData['others']) $hasChanges = true;

    if (!$hasChanges) {
        // No changes were made, display alert and redirect back to view_hosting_table.php
        echo '<script type="text/javascript">';
        echo 'alert("No changes made.");';
        echo 'window.location.href="view_hosting_table.php?debtor_code=' . urlencode($debtorCode) . '";';
        echo '</script>';
    } else {
        // Update the hosting domain in the database
        $stmt = $pdo->prepare('UPDATE item_type_hosting_domain SET active = :active, domain_name = :domain_name, server_name = :server_name, register_on = :register_on, service_provider = :service_provider, updated_time = NOW(), others = :others WHERE debtor_code = :debtor_code AND item_type_hosting_domain_id = :item_type_hosting_domain_id');
        $success = $stmt->execute([
            ':active' => $active,
            ':domain_name' => $domain_name,
            ':server_name' => $server_names_string,
            ':register_on' => $register_on,
            ':service_provider' => $service_provider,
            ':others' => $others,
            ':debtor_code' => $debtorCode,
            ':item_type_hosting_domain_id' => $hostingDomainId
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_hosting_domain WHERE debtor_code = :debtor_code AND item_type_hosting_domain_id = :item_type_hosting_domain_id LIMIT 1');
            $stmt->execute([':debtor_code' => $debtorCode, ':item_type_hosting_domain_id' => $hostingDomainId]);
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in hosting domain item (Debtor Code: " . $debtorCode . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_hosting_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            // If update failed, show error message
            echo '<script type="text/javascript">';
            echo 'alert("Failed to update. Please try again.");';
            echo '</script>';
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Hosting Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Hosting Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_hosting_id" value="<?= htmlspecialchars($hostingId) ?>">

           <!-- Active Status -->
<div class="card mb-3">
    <div class="card-header">
        <h5 class="mb-0">Active Status</h5>
    </div>
    <div class="card-body">
        <div class="form-check">
            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $hostingDomain['active'] ? 'checked' : '' ?>>
            <label class="form-check-label" for="active">Active</label>
        </div>
    </div>
</div>

<!-- Domain Details -->
<div class="card mb-3">
    <div class="card-header">
        <h5 class="card-title">Domain Details</h5>
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-md-6">
                <div class="form-floating mb-3">
                    <input type="text" name="domain_name" id="domain_name" class="form-control" value="<?= htmlspecialchars($hostingDomain['domain_name'] ?? '') ?>" placeholder="Domain Name">
                    <label for="domain_name">Domain Name</label>
                </div>
            </div>
            <div class="col-md-6">
                <div class="form-floating mb-3">
                    <input type="date" name="register_on" id="register_on" class="form-control" value="<?= htmlspecialchars($hostingDomain['register_on'] ?? '') ?>" placeholder="Register On">
                    <label for="register_on">Register On</label>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Server Names -->
<div class="card mb-3">
    <div class="card-header">
        <h5 class="card-title">Server Names</h5>
    </div>
    <div class="card-body">
        <div class="mb-3 row">
            <label for="server_name" class="col-md-12 col-form-label">Server Names:</label>
            <div class="col-md-12" id="server-container">
                <?php
                $server_names = explode(", ", $hostingDomain['server_name']);
                foreach ($server_names as $server_name) {
                    if (!empty(trim($server_name))) {
                        echo '<div class="input-group mb-2">';
                        echo '<div class="form-floating">';
                        echo '<input type="text" class="form-control form-control-custom" name="server_name[]" value="' . htmlspecialchars($server_name) . '" placeholder="Server Name">';
                        echo '<label for="server_name">Server Name</label>';
                        echo '</div>';
                        echo '<button type="button" class="btn btn-danger" onclick="removeServerField(this)">Remove</button>';
                        echo '</div>';
                    }
                }
                ?>
            </div>
            <div class="col-md-12 mt-2">
                <button type="button" class="btn btn-secondary" onclick="addServerField()">Add</button>
            </div>
        </div>
    </div>
</div>

<!-- Service Provider -->
<div class="card mb-3">
    <div class="card-header">
        <h5 class="card-title">Service Provider</h5>
    </div>
    <div class="card-body">
        <div class="form-floating mb-3">
            <input type="text" name="service_provider" id="service_provider" class="form-control" value="<?= htmlspecialchars($hostingDomain['service_provider'] ?? '') ?>" placeholder="Service Provider">
            <label for="service_provider">Service Provider</label>
        </div>
    </div>
</div>

<!-- Others Information -->
<div class="card mb-3">
    <div class="card-header">
        <h5 class="mb-0">Others Information</h5>
    </div>
    <div class="card-body">
        <div class="form-floating mb-3">
            <textarea 
                id="others" 
                name="others" 
                class="form-control" 
                placeholder="Others" 
                style="height: 200px; resize: vertical; overflow-y: hidden;"
                oninput="this.style.height = ''; this.style.height = this.scrollHeight + 'px';"
            ><?= htmlspecialchars($hostingDomain['others'] ?? '') ?></textarea>
            <label for="others">Others</label>
        </div>
    </div>
</div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- JavaScript for dynamic server name fields -->
<script>
    function addServerField() {
        const container = document.getElementById('server-container');
        const newField = document.createElement('div');
        newField.className = 'input-group mb-2';
        newField.innerHTML = `
            <div class="form-floating">
                <input type="text" class="form-control form-control-custom" name="server_name[]" placeholder="Server Name">
                <label for="server_name">Server Name</label>
            </div>
            <button type="button" class="btn btn-danger" onclick="removeServerField(this)">Remove</button>
        `;
        container.appendChild(newField);
    }

    function removeServerField(button) {
        const container = document.getElementById('server-container');
        if (container.childElementCount > 1) {
            button.parentElement.remove();
        } else {
            alert("Cannot remove the last field.");
        }
    }
</script>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

