<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_hw_printer_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_hw_printer_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $printerId = $_GET['item_type_hw_printer_id'];

    // Fetch the printer details based on debtor_code and item_type_hw_printer_id
    $stmt = $pdo->prepare('SELECT * FROM item_type_hw_printer WHERE debtor_code = :debtor_code AND item_type_hw_printer_id = :item_type_hw_printer_id LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_type_hw_printer_id', $printerId);
    $stmt->execute();
    $printer = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$printer) {
        echo "<p>No printer found with the provided ID.</p>";
        exit;
    }

    // Fetch the company name based on debtor_code
    $companyName = 'Unknown Company'; // Default fallback
    if ($debtorCode) {
        try {
            $stmt = $pdo->prepare("SELECT company_name FROM company_info WHERE debtor_code = :debtor_code LIMIT 1");
            $stmt->execute([':debtor_code' => $debtorCode]);
            $company = $stmt->fetch(PDO::FETCH_ASSOC);
            if ($company) {
                $companyName = $company['company_name'];
            }
        } catch (PDOException $e) {
            error_log('Database query error: ' . $e->getMessage());
        }
    }
} else {
    echo "<p>No debtor code or printer ID provided.</p>";
    exit;
}

// Fetch the list of installed PCs for the selected company based on debtor_code and company_name
$installedPcs = [];
if ($debtorCode && isset($printer['company_name'])) {
    $companyName = $printer['company_name'];
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $brand = htmlspecialchars($_POST['brand']);
    $model = htmlspecialchars($_POST['model']);
    $port = htmlspecialchars($_POST['port']);
    $serial_number = htmlspecialchars($_POST['serial_number']);
    $installed_pc = htmlspecialchars($_POST['installed_pc']);
    $others = htmlspecialchars($_POST['others']);
    $department = htmlspecialchars($_POST['department']);
    $type = htmlspecialchars($_POST['type']);
    $tcp_ip = htmlspecialchars($_POST['tcp_ip']);

    // Validate that the type is selected
    if (empty($type) || $type === 'Please select a type') {
        echo "<script>alert('Please select a type.');</script>";
    } else {
        // Store the old data for comparison
        $oldData = $printer;

        // Check if any data has changed
        $dataChanged = false;
        if ($active != $oldData['active'] ||
            $brand != $oldData['brand'] ||
            $model != $oldData['model'] ||
            $port != $oldData['port'] ||
            $serial_number != $oldData['serial_number'] ||
            $installed_pc != $oldData['installed_pc'] ||
            $others != $oldData['others'] ||
            $department != $oldData['department'] ||
            $type != $oldData['type'] ||
            $tcp_ip != $oldData['tcp_ip']) {
            $dataChanged = true;
        }

        if (!$dataChanged) {
            // No data changed, display message and exit
            echo '<script type="text/javascript">';
            echo 'alert("No data changed.");';
            echo 'window.location.href="view_hardware_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
            exit;
        }

        // Update the printer in the database
        $stmt = $pdo->prepare('UPDATE item_type_hw_printer SET active = :active, brand = :brand, model = :model, port = :port, serial_number = :serial_number, installed_pc = :installed_pc, others = :others, department = :department, type = :type, tcp_ip = :tcp_ip, updated_time = NOW() WHERE debtor_code = :debtor_code AND item_type_hw_printer_id = :item_type_hw_printer_id');
        $stmt->bindParam(':active', $active);
        $stmt->bindParam(':brand', $brand);
        $stmt->bindParam(':model', $model);
        $stmt->bindParam(':port', $port);
        $stmt->bindParam(':serial_number', $serial_number);
        $stmt->bindParam(':installed_pc', $installed_pc);
        $stmt->bindParam(':others', $others);
        $stmt->bindParam(':department', $department);
        $stmt->bindParam(':type', $type);
        $stmt->bindParam(':tcp_ip', $tcp_ip);
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->bindParam(':item_type_hw_printer_id', $printerId);

        if ($stmt->execute()) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_hw_printer WHERE debtor_code = :debtor_code AND item_type_hw_printer_id = :item_type_hw_printer_id LIMIT 1');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->bindParam(':item_type_hw_printer_id', $printerId);
            $stmt->execute();
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in printer item (Company Name: " . $companyName . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_hardware_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            // If update failed, show error message
            echo '<script type="text/javascript">';
            echo 'alert("Failed to update. Please try again.");';
            echo '</script>';
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Printer Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Printer Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_hw_id" value="<?= htmlspecialchars($printerId) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $printer['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Hardware Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Hardware Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="brand" id="brand" placeholder="Brand" value="<?= htmlspecialchars($printer['brand'] ?? '') ?>">
                                    <label for="brand">Brand</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="model" id="model" placeholder="Model" value="<?= htmlspecialchars($printer['model'] ?? '') ?>">
                                    <label for="model">Model</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="department" id="department" placeholder="Department" value="<?= htmlspecialchars($printer['department'] ?? '') ?>">
                                    <label for="department">Department</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="serial_number" id="serial_number" placeholder="Serial Number" value="<?= htmlspecialchars($printer['serial_number'] ?? '') ?>">
                                    <label for="serial_number">Serial Number</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <select class="form-select" name="port" id="port">
                                        <option value="USB" <?= isset($printer['port']) && $printer['port'] == 'USB' ? 'selected' : '' ?>>USB</option>
                                        <option value="BT" <?= isset($printer['port']) && $printer['port'] == 'BT' ? 'selected' : '' ?>>BT</option>
                                        <option value="WIFI" <?= isset($printer['port']) && $printer['port'] == 'WIFI' ? 'selected' : '' ?>>WIFI</option>
                                        <option value="NETWORK" <?= isset($printer['port']) && $printer['port'] == 'NETWORK' ? 'selected' : '' ?>>NETWORK</option>
                                        <option value="COM" <?= isset($printer['port']) && $printer['port'] == 'COM' ? 'selected' : '' ?>>COM</option>
                                        <option value="PARALLEL" <?= isset($printer['port']) && $printer['port'] == 'PARALLEL' ? 'selected' : '' ?>>PARALLEL</option>
                                    </select>
                                    <label for="port">Port</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <select class="form-select" name="type" id="type" required>
                                        <option value="Please select a type">Please select a type</option>
                                        <option value="Copier" <?= isset($printer['type']) && $printer['type'] == 'Copier' ? 'selected' : '' ?>>Copier</option>
                                        <option value="Printer" <?= isset($printer['type']) && $printer['type'] == 'Printer' ? 'selected' : '' ?>>Printer</option>
                                    </select>
                                    <label for="type">Type</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="tcp_ip" id="tcp_ip" placeholder="TCP/IP Address" value="<?= htmlspecialchars($printer['tcp_ip'] ?? '') ?>">
                                    <label for="tcp_ip">TCP/IP Address</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- PC Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="installed_pc" name="installed_pc" data-placeholder="Choose anything">
                                        <option></option> <!-- Placeholder option -->
                                        <?php foreach ($installedPcs as $option): ?>
                                            <option value="<?= htmlspecialchars($option) ?>" <?= isset($printer['installed_pc']) && $printer['installed_pc'] == $option ? 'selected' : '' ?>><?= htmlspecialchars($option) ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating">
                            <textarea class="form-control" id="others" name="others" placeholder="Others" style="height: 100px"><?= htmlspecialchars($printer['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Update</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: $(this).data('placeholder'),
        });
    });
</script>

