<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if item_type_nas_ab_google_id is passed via URL
if (!isset($_GET['item_type_nas_ab_google_id'])) {
    echo "<p>No NAS ID provided.</p>";
    exit;
}

$itemTypeNasAbGoogleId = $_GET['item_type_nas_ab_google_id'];

// Fetch the NAS details based on item_type_nas_ab_google_id
$stmt = $pdo->prepare('SELECT * FROM item_type_nas_ab_google WHERE item_type_nas_ab_google_id = :item_type_nas_ab_google_id LIMIT 1');
$stmt->execute([':item_type_nas_ab_google_id' => $itemTypeNasAbGoogleId]);
$nasDetails = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$nasDetails) {
    echo "<p>No NAS details found with the provided ID.</p>";
    exit;
}

// Fetch the company name based on debtor_code
$companyName = 'Unknown Company'; // Default fallback
if ($nasDetails['debtor_code']) {
    try {
        $stmt = $pdo->prepare("SELECT company_name FROM company_info WHERE debtor_code = :debtor_code LIMIT 1");
        $stmt->execute([':debtor_code' => $nasDetails['debtor_code']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $companyName = $company['company_name'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs from the database
$installedPcs = [];
try {
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc");
    $stmt->execute();
    $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $abGDomainForBackup = htmlspecialchars($_POST['ab_g_domain_for_backup']);
    $abGServiceFrom = htmlspecialchars($_POST['ab_g_service_from']);
    $abGServiceToFolder = htmlspecialchars($_POST['ab_g_service_to_folder']);
    $abGServiceSchedule = htmlspecialchars($_POST['ab_g_service_schedule']);
    $abGServiceTime = htmlspecialchars($_POST['ab_g_service_time']);
    $abGPreviousVersionDays = htmlspecialchars($_POST['ab_g_previous_version_days']);
    $abGAcc = htmlspecialchars($_POST['ab_g_acc']);
    $abGTenantId = htmlspecialchars($_POST['ab_g_tenant_id']);
    $abGAppId = htmlspecialchars($_POST['ab_g_app_id']);

    // Handle certificate file upload
    $abGCertificateFile = $nasDetails['ab_g_certificate_file']; // Default to the current certificate file
    if (isset($_FILES['ab_g_certificate_file']) && $_FILES['ab_g_certificate_file']['error'] == 0) {
        $uploadDir = '/crm/images/NAS/Active Backup for Google/';
        $absoluteUploadDir = $_SERVER['DOCUMENT_ROOT'] . $uploadDir;

        // Ensure the directory exists
        if (!is_dir($absoluteUploadDir)) {
            if (!mkdir($absoluteUploadDir, 0777, true)) {
                echo "<script>alert('Failed to create directory. Please check permissions.');</script>";
                exit;
            }
        }

        $uploadFile = $absoluteUploadDir . basename($_FILES['ab_g_certificate_file']['name']);
        $fileType = strtolower(pathinfo($uploadFile, PATHINFO_EXTENSION));

        // Generate a garbled name for the file
        $garbledName = substr(md5(uniqid(rand(), true)), 0, 20) . '.' . $fileType;
        $uploadFile = $absoluteUploadDir . $garbledName;

        // Move the uploaded file to the desired directory
        if (move_uploaded_file($_FILES['ab_g_certificate_file']['tmp_name'], $uploadFile)) {
            // Delete the old certificate file if it exists
            if (!empty($nasDetails['ab_g_certificate_file'])) {
                $oldCertificatePath = $_SERVER['DOCUMENT_ROOT'] . $nasDetails['ab_g_certificate_file'];
                if (file_exists($oldCertificatePath)) {
                    unlink($oldCertificatePath);
                }
            }
            $abGCertificateFile = $uploadDir . $garbledName; // Save the relative path in the database
        } else {
            echo "<script>alert('Failed to upload certificate file. Please try again.');</script>";
        }
    }

    // Store the old data for comparison
    $oldData = $nasDetails;

    // Check if any data has changed
    $dataChanged = false;
    if ($active != $oldData['active'] ||
        $abGDomainForBackup != $oldData['ab_g_domain_for_backup'] ||
        $abGServiceFrom != $oldData['ab_g_service_from'] ||
        $abGServiceToFolder != $oldData['ab_g_service_to_folder'] ||
        $abGServiceSchedule != $oldData['ab_g_service_schedule'] ||
        $abGServiceTime != $oldData['ab_g_service_time'] ||
        $abGPreviousVersionDays != $oldData['ab_g_previous_version_days'] ||
        $abGAcc != $oldData['ab_g_acc'] ||
        $abGTenantId != $oldData['ab_g_tenant_id'] ||
        $abGAppId != $oldData['ab_g_app_id'] ||
        $abGCertificateFile != $oldData['ab_g_certificate_file']) {
        $dataChanged = true;
    }

    if (!$dataChanged) {
        // If no data changed, show alert and redirect back to view_nas_table.php
        echo '<script type="text/javascript">';
        echo 'alert("No data changed.");';
        echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasDetails['debtor_code']) . '&company_name=' . urlencode($nasDetails['company_name']) . '";';
        echo '</script>';
    } else {
        // Update the NAS details in the database
        $stmt = $pdo->prepare('UPDATE item_type_nas_ab_google SET 
            active = :active,
            ab_g_domain_for_backup = :ab_g_domain_for_backup,
            ab_g_service_from = :ab_g_service_from,
            ab_g_service_to_folder = :ab_g_service_to_folder,
            ab_g_service_schedule = :ab_g_service_schedule,
            ab_g_service_time = :ab_g_service_time,
            ab_g_previous_version_days = :ab_g_previous_version_days,
            ab_g_acc = :ab_g_acc,
            ab_g_tenant_id = :ab_g_tenant_id,
            ab_g_app_id = :ab_g_app_id,
            ab_g_certificate_file = :ab_g_certificate_file,
            updated_time = NOW()
            WHERE item_type_nas_ab_google_id = :item_type_nas_ab_google_id');

        $success = $stmt->execute([
            ':active' => $active,
            ':ab_g_domain_for_backup' => $abGDomainForBackup,
            ':ab_g_service_from' => $abGServiceFrom,
            ':ab_g_service_to_folder' => $abGServiceToFolder,
            ':ab_g_service_schedule' => $abGServiceSchedule,
            ':ab_g_service_time' => $abGServiceTime,
            ':ab_g_previous_version_days' => $abGPreviousVersionDays,
            ':ab_g_acc' => $abGAcc,
            ':ab_g_tenant_id' => $abGTenantId,
            ':ab_g_app_id' => $abGAppId,
            ':ab_g_certificate_file' => $abGCertificateFile,
            ':item_type_nas_ab_google_id' => $itemTypeNasAbGoogleId
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_nas_ab_google WHERE item_type_nas_ab_google_id = :item_type_nas_ab_google_id LIMIT 1');
            $stmt->execute([':item_type_nas_ab_google_id' => $itemTypeNasAbGoogleId]);
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in Active Backup for Google (Company Name: " . $companyName . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasDetails['debtor_code']) . '&company_name=' . urlencode($nasDetails['company_name']) . '";';
            echo '</script>';
        } else {
            // If update failed, show error message
            echo '<script type="text/javascript">';
            echo 'alert("Failed to update. Please try again.");';
            echo '</script>';
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit NAS Active Backup for Google Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit NAS Active Backup for Google Details</h1>
        </div>
        <div class="card-body">
            <form method="POST" enctype="multipart/form-data">
                <input type="hidden" name="item_type_nas_id" value="<?= htmlspecialchars($itemTypeNasId) ?>">
                
                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $nasDetails['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>
                
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Active Backup for Google</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_domain_for_backup" id="ab_g_domain_for_backup" placeholder="Active Backup for Google Domain For Backup" value="<?= htmlspecialchars($nasDetails['ab_g_domain_for_backup'] ?? '') ?>">
                                    <label for="ab_g_domain_for_backup">Active Backup for Google Domain For Backup</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_service_from" id="ab_g_service_from" placeholder="Active Backup for Google Service From" value="<?= htmlspecialchars($nasDetails['ab_g_service_from'] ?? '') ?>">
                                    <label for="ab_g_service_from">Active Backup for Google Service From</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_service_to_folder" id="ab_g_service_to_folder" placeholder="Active Backup for Google Service To Folder" value="<?= htmlspecialchars($nasDetails['ab_g_service_to_folder'] ?? '') ?>">
                                    <label for="ab_g_service_to_folder">Active Backup for Google Service To Folder</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_service_schedule" id="ab_g_service_schedule" placeholder="Active Backup for Google Service Schedule" value="<?= htmlspecialchars($nasDetails['ab_g_service_schedule'] ?? '') ?>">
                                    <label for="ab_g_service_schedule">Active Backup for Google Service Schedule</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="time" class="form-control" name="ab_g_service_time" id="ab_g_service_time" placeholder="Active Backup for Google Service Time" value="<?= htmlspecialchars($nasDetails['ab_g_service_time'] ?? '') ?>">
                                    <label for="ab_g_service_time">Active Backup for Google Service Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_previous_version_days" id="ab_g_previous_version_days" placeholder="Active Backup for Google Keep Previous Version of Days" value="<?= htmlspecialchars($nasDetails['ab_g_previous_version_days'] ?? '') ?>">
                                    <label for="ab_g_previous_version_days">Active Backup for Google Keep Previous Version of Days</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_acc" id="ab_g_acc" placeholder="Active Backup for Google Account" value="<?= htmlspecialchars($nasDetails['ab_g_acc'] ?? '') ?>">
                                    <label for="ab_g_acc">Active Backup for Google Account</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_tenant_id" id="ab_g_tenant_id" placeholder="Active Backup for Google Tenant ID" value="<?= htmlspecialchars($nasDetails['ab_g_tenant_id'] ?? '') ?>">
                                    <label for="ab_g_tenant_id">Active Backup for Google Tenant ID</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_app_id" id="ab_g_app_id" placeholder="Active Backup for Google Application ID" value="<?= htmlspecialchars($nasDetails['ab_g_app_id'] ?? '') ?>">
                                    <label for="ab_g_app_id">Active Backup for Google Application ID</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Certificate File for Google Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Certificate File for Google</h5>
                    </div>
                    <div class="card-body">
                        <div class="mb-3">
                            <label for="ab_g_certificate_file" class="form-label">Upload Certificate File for Google</label>
                            <input type="file" class="form-control" name="ab_g_certificate_file" id="ab_g_certificate_file">
                        </div>

                        <!-- Display the current certificate file -->
                        <?php if (!empty($nasDetails['ab_g_certificate_file'])): ?>
                            <div class="form-group">
                                <label>Current Certificate File</label>
                                <div class="d-flex align-items-center">
                                    <p class="ml-3"><?= htmlspecialchars(basename($nasDetails['ab_g_certificate_file'])) ?></p>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

