<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if item_type_nas_fs_id is passed via URL
if (!isset($_GET['item_type_nas_fs_id'])) {
    echo "<p>No NAS FS ID provided.</p>";
    exit;
}

$itemTypeNasFsId = $_GET['item_type_nas_fs_id'];

// Fetch the NAS FS details based on item_type_nas_fs_id
$stmt = $pdo->prepare('SELECT * FROM item_type_nas_fs WHERE item_type_nas_fs_id = :item_type_nas_fs_id LIMIT 1');
$stmt->execute([':item_type_nas_fs_id' => $itemTypeNasFsId]);
$nasFsDetails = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$nasFsDetails) {
    echo "<p>No NAS FS details found with the provided ID.</p>";
    exit;
}

// Fetch the company name based on debtor_code
$companyName = 'Unknown Company'; // Default fallback
if ($nasFsDetails['debtor_code']) {
    try {
        $stmt = $pdo->prepare("SELECT company_name FROM company_info WHERE debtor_code = :debtor_code LIMIT 1");
        $stmt->execute([':debtor_code' => $nasFsDetails['debtor_code']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $companyName = $company['company_name'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs for the selected company based on debtor_code and company_name
$installedPcs = [];
if ($nasFsDetails['debtor_code'] && $nasFsDetails['company_name']) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $nasFsDetails['debtor_code'], ':company_name' => $nasFsDetails['company_name']]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $fsServiceName = htmlspecialchars($_POST['fs_service_name']);
    $fsServiceFrom = htmlspecialchars($_POST['fs_service_from']);
    $fsServiceToFolder = htmlspecialchars($_POST['fs_service_to_folder']);
    $fsServiceSchedule = htmlspecialchars($_POST['fs_service_schedule']);
    $fsServiceTime = htmlspecialchars($_POST['fs_service_time']);
    $fsServiceRetention = htmlspecialchars($_POST['fs_service_retention']);
    $fsInstalledPc = htmlspecialchars($_POST['fs_installed_pc']);

    // Store the old data for comparison
    $oldData = $nasFsDetails;

    // Check if any data has changed
    $dataChanged = false;
    if ($active != $oldData['active'] ||
        $fsServiceName != $oldData['fs_service_name'] ||
        $fsServiceFrom != $oldData['fs_service_from'] ||
        $fsServiceToFolder != $oldData['fs_service_to_folder'] ||
        $fsServiceSchedule != $oldData['fs_service_schedule'] ||
        $fsServiceTime != $oldData['fs_service_time'] ||
        $fsServiceRetention != $oldData['fs_service_retention'] ||
        $fsInstalledPc != $oldData['fs_installed_pc']) {
        $dataChanged = true;
    }

    if (!$dataChanged) {
        // If no data changed, show alert and redirect back to view_nas_fs_table.php
        echo '<script type="text/javascript">';
        echo 'alert("No data changed.");';
        echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasFsDetails['debtor_code']) . '&company_name=' . urlencode($nasFsDetails['company_name']) . '";';
        echo '</script>';
    } else {
        // Update the NAS FS details in the database
        $stmt = $pdo->prepare('UPDATE item_type_nas_fs SET 
            active = :active,
            fs_service_name = :fs_service_name,
            fs_service_from = :fs_service_from,
            fs_service_to_folder = :fs_service_to_folder,
            fs_service_schedule = :fs_service_schedule,
            fs_service_time = :fs_service_time,
            fs_service_retention = :fs_service_retention,
            fs_installed_pc = :fs_installed_pc,
            updated_time = NOW()
            WHERE item_type_nas_fs_id = :item_type_nas_fs_id');

        $success = $stmt->execute([
            ':active' => $active,
            ':fs_service_name' => $fsServiceName,
            ':fs_service_from' => $fsServiceFrom,
            ':fs_service_to_folder' => $fsServiceToFolder,
            ':fs_service_schedule' => $fsServiceSchedule,
            ':fs_service_time' => $fsServiceTime,
            ':fs_service_retention' => $fsServiceRetention,
            ':fs_installed_pc' => $fsInstalledPc,
            ':item_type_nas_fs_id' => $itemTypeNasFsId
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_nas_fs WHERE item_type_nas_fs_id = :item_type_nas_fs_id LIMIT 1');
            $stmt->execute([':item_type_nas_fs_id' => $itemTypeNasFsId]);
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in Active Backup File Server (Company Name: " . $companyName . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasFsDetails['debtor_code']) . '&company_name=' . urlencode($nasFsDetails['company_name']) . '";';
            echo '</script>';
        } else {
            // If update failed, show error message
            echo '<script type="text/javascript">';
            echo 'alert("Failed to update. Please try again.");';
            echo '</script>';
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit NAS File Server Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit NAS File Server Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="item_type_nas_id" value="<?= htmlspecialchars($itemTypeNasId) ?>">
                
                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $nasFsDetails['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>
                
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Active Backup File Server</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="fs_service_name" id="fs_service_name" placeholder="File Server Service Name" value="<?= htmlspecialchars($nasFsDetails['fs_service_name'] ?? '') ?>">
                                    <label for="fs_service_name">File Server Service Name</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="fs_service_from" id="fs_service_from" placeholder="File Server Service From" value="<?= htmlspecialchars($nasFsDetails['fs_service_from'] ?? '') ?>">
                                    <label for="fs_service_from">File Server Service From</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="fs_service_to_folder" id="fs_service_to_folder" placeholder="File Server Service To Folder" value="<?= htmlspecialchars($nasFsDetails['fs_service_to_folder'] ?? '') ?>">
                                    <label for="fs_service_to_folder">File Server Service To Folder</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="fs_service_schedule" id="fs_service_schedule" placeholder="File Server Service Schedule" value="<?= htmlspecialchars($nasFsDetails['fs_service_schedule'] ?? '') ?>">
                                    <label for="fs_service_schedule">File Server Service Schedule</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="time" class="form-control" name="fs_service_time" id="fs_service_time" placeholder="File Server Service Time" value="<?= htmlspecialchars($nasFsDetails['fs_service_time'] ?? '') ?>">
                                    <label for="fs_service_time">File Server Service Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="fs_service_retention" id="fs_service_retention" placeholder="File Server Service Retention" value="<?= htmlspecialchars($nasFsDetails['fs_service_retention'] ?? '') ?>">
                                    <label for="fs_service_retention">File Server Service Retention</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <select class="form-select" name="fs_installed_pc" id="fs_installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($installedPcs as $pc): ?>
                                            <option value="<?= htmlspecialchars($pc) ?>" <?= $pc == $nasFsDetails['fs_installed_pc'] ? 'selected' : '' ?>><?= htmlspecialchars($pc) ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="fs_installed_pc">File Server Installed PC</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

