<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if item_type_nas_hb_id is passed via URL
if (!isset($_GET['item_type_nas_hb_id'])) {
    echo "<p>No NAS ID provided.</p>";
    exit;
}

$itemTypeNasHbId = $_GET['item_type_nas_hb_id'];

// Fetch the NAS details based on item_type_nas_hb_id
$stmt = $pdo->prepare('SELECT * FROM item_type_nas_hb WHERE item_type_nas_hb_id = :item_type_nas_hb_id LIMIT 1');
$stmt->execute([':item_type_nas_hb_id' => $itemTypeNasHbId]);
$nasDetails = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$nasDetails) {
    echo "<p>No NAS details found with the provided ID.</p>";
    exit;
}

// Fetch the company name based on debtor_code
$companyName = 'Unknown Company'; // Default fallback
if ($nasDetails['debtor_code']) {
    try {
        $stmt = $pdo->prepare("SELECT company_name FROM company_info WHERE debtor_code = :debtor_code LIMIT 1");
        $stmt->execute([':debtor_code' => $nasDetails['debtor_code']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $companyName = $company['company_name'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs for the selected company based on debtor_code and company_name
$installedPcs = [];
if ($nasDetails['debtor_code'] && $nasDetails['company_name']) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $nasDetails['debtor_code'], ':company_name' => $nasDetails['company_name']]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $hbServiceName = htmlspecialchars($_POST['hb_service_name']);
    $hbServiceFrom = htmlspecialchars($_POST['hb_service_from']);
    $hbServiceToFolder = htmlspecialchars($_POST['hb_service_to_folder']);
    $hbServiceSchedule = htmlspecialchars($_POST['hb_service_schedule']);
    $hbServiceTime = htmlspecialchars($_POST['hb_service_time']);
    $hbServiceRetention = htmlspecialchars($_POST['hb_service_retention']);
    $hbServiceSecSynology = htmlspecialchars($_POST['hb_service_sec_synology']);
    $hbServiceExtHd = htmlspecialchars($_POST['hb_service_ext_hd']);

    // Store the old data for comparison
    $oldData = $nasDetails;

    // Check if any data has changed
    $dataChanged = false;
    if ($active != $oldData['active'] ||
        $hbServiceName != $oldData['hb_service_name'] ||
        $hbServiceFrom != $oldData['hb_service_from'] ||
        $hbServiceToFolder != $oldData['hb_service_to_folder'] ||
        $hbServiceSchedule != $oldData['hb_service_schedule'] ||
        $hbServiceTime != $oldData['hb_service_time'] ||
        $hbServiceRetention != $oldData['hb_service_retention'] ||
        $hbServiceSecSynology != $oldData['hb_service_sec_synology'] ||
        $hbServiceExtHd != $oldData['hb_service_ext_hd']) {
        $dataChanged = true;
    }

    if (!$dataChanged) {
        // If no data changed, show alert and redirect back to view_nas_table.php
        echo '<script type="text/javascript">';
        echo 'alert("No data changed.");';
        echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasDetails['debtor_code']) . '&company_name=' . urlencode($nasDetails['company_name']) . '";';
        echo '</script>';
    } else {
        // Update the NAS details in the database
        $stmt = $pdo->prepare('UPDATE item_type_nas_hb SET 
            active = :active,
            hb_service_name = :hb_service_name,
            hb_service_from = :hb_service_from,
            hb_service_to_folder = :hb_service_to_folder,
            hb_service_schedule = :hb_service_schedule,
            hb_service_time = :hb_service_time,
            hb_service_retention = :hb_service_retention,
            hb_service_sec_synology = :hb_service_sec_synology,
            hb_service_ext_hd = :hb_service_ext_hd,
            updated_time = NOW()
            WHERE item_type_nas_hb_id = :item_type_nas_hb_id');

        $success = $stmt->execute([
            ':active' => $active,
            ':hb_service_name' => $hbServiceName,
            ':hb_service_from' => $hbServiceFrom,
            ':hb_service_to_folder' => $hbServiceToFolder,
            ':hb_service_schedule' => $hbServiceSchedule,
            ':hb_service_time' => $hbServiceTime,
            ':hb_service_retention' => $hbServiceRetention,
            ':hb_service_sec_synology' => $hbServiceSecSynology,
            ':hb_service_ext_hd' => $hbServiceExtHd,
            ':item_type_nas_hb_id' => $itemTypeNasHbId
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_nas_hb WHERE item_type_nas_hb_id = :item_type_nas_hb_id LIMIT 1');
            $stmt->execute([':item_type_nas_hb_id' => $itemTypeNasHbId]);
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in Hyper Backup (Company Name: " . $companyName . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasDetails['debtor_code']) . '&company_name=' . urlencode($nasDetails['company_name']) . '";';
            echo '</script>';
        } else {
            // If update failed, show error message
            echo '<script type="text/javascript">';
            echo 'alert("Failed to update. Please try again.");';
            echo '</script>';
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit NAS Hyper Backup Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit NAS Hyper Backup Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="item_type_nas_id" value="<?= htmlspecialchars($itemTypeNasId) ?>">
                   
                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $nasDetails['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Active Backup Hyper Backup</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_name" id="hb_service_name" placeholder="Hyper Backup Service Name" value="<?= htmlspecialchars($nasDetails['hb_service_name'] ?? '') ?>">
                                    <label for="hb_service_name">Hyper Backup Service Name</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_from" id="hb_service_from" placeholder="Hyper Backup Service From" value="<?= htmlspecialchars($nasDetails['hb_service_from'] ?? '') ?>">
                                    <label for="hb_service_from">Hyper Backup Service From</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_to_folder" id="hb_service_to_folder" placeholder="Hyper Backup Service To Folder" value="<?= htmlspecialchars($nasDetails['hb_service_to_folder'] ?? '') ?>">
                                    <label for="hb_service_to_folder">Hyper Backup Service To Folder</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_schedule" id="hb_service_schedule" placeholder="Hyper Backup Service Schedule" value="<?= htmlspecialchars($nasDetails['hb_service_schedule'] ?? '') ?>">
                                    <label for="hb_service_schedule">Hyper Backup Service Schedule</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="time" class="form-control" name="hb_service_time" id="hb_service_time" placeholder="Hyper Backup Service Time" value="<?= htmlspecialchars($nasDetails['hb_service_time'] ?? '') ?>">
                                    <label for="hb_service_time">Hyper Backup Service Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_retention" id="hb_service_retention" placeholder="Hyper Backup Service Retention" value="<?= htmlspecialchars($nasDetails['hb_service_retention'] ?? '') ?>">
                                    <label for="hb_service_retention">Hyper Backup Service Retention</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_sec_synology" id="hb_service_sec_synology" placeholder="Service Second Synology" value="<?= htmlspecialchars($nasDetails['hb_service_sec_synology'] ?? '') ?>">
                                    <label for="hb_service_sec_synology">Service Second Synology</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_ext_hd" id="hb_service_ext_hd" placeholder="Service Extend Hard Disk" value="<?= htmlspecialchars($nasDetails['hb_service_ext_hd'] ?? '') ?>">
                                    <label for="hb_service_ext_hd">Service Extend Hard Disk</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

