<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if item_type_nas_pb_id is passed via URL
if (!isset($_GET['item_type_nas_pb_id'])) {
    echo "<p>No NAS PB ID provided.</p>";
    exit;
}

$itemTypeNasPbId = $_GET['item_type_nas_pb_id'];

// Fetch the NAS PB details based on item_type_nas_pb_id
$stmt = $pdo->prepare('SELECT * FROM item_type_nas_pb WHERE item_type_nas_pb_id = :item_type_nas_pb_id LIMIT 1');
$stmt->execute([':item_type_nas_pb_id' => $itemTypeNasPbId]);
$nasPbDetails = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$nasPbDetails) {
    echo "<p>No NAS PB details found with the provided ID.</p>";
    exit;
}

// Fetch the company name based on debtor_code
$companyName = 'Unknown Company'; // Default fallback
if ($nasPbDetails['debtor_code']) {
    try {
        $stmt = $pdo->prepare("SELECT company_name FROM company_info WHERE debtor_code = :debtor_code LIMIT 1");
        $stmt->execute([':debtor_code' => $nasPbDetails['debtor_code']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $companyName = $company['company_name'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs for the selected company based on debtor_code and company_name
$installedPcs = [];
if ($nasPbDetails['debtor_code'] && $nasPbDetails['company_name']) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $nasPbDetails['debtor_code'], ':company_name' => $nasPbDetails['company_name']]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $pbServiceName = htmlspecialchars($_POST['pb_service_name']);
    $pbServiceFrom = htmlspecialchars($_POST['pb_service_from']);
    $pbServiceToFolder = htmlspecialchars($_POST['pb_service_to_folder']);
    $pbServiceSchedule = htmlspecialchars($_POST['pb_service_schedule']);
    $pbServiceTime = htmlspecialchars($_POST['pb_service_time']);
    $pbServiceRetention = htmlspecialchars($_POST['pb_service_retention']);
    $pbInstalledPc = htmlspecialchars($_POST['pb_installed_pc']);

    // Store the old data for comparison
    $oldData = $nasPbDetails;

    // Check if any data has changed
    $dataChanged = false;
    if ($active != $oldData['active'] ||
        $pbServiceName != $oldData['pb_service_name'] ||
        $pbServiceFrom != $oldData['pb_service_from'] ||
        $pbServiceToFolder != $oldData['pb_service_to_folder'] ||
        $pbServiceSchedule != $oldData['pb_service_schedule'] ||
        $pbServiceTime != $oldData['pb_service_time'] ||
        $pbServiceRetention != $oldData['pb_service_retention'] ||
        $pbInstalledPc != $oldData['pb_installed_pc']) {
        $dataChanged = true;
    }

    if (!$dataChanged) {
        // If no data changed, show alert and redirect back to view_nas_table.php
        echo '<script type="text/javascript">';
        echo 'alert("No data changed.");';
        echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasPbDetails['debtor_code']) . '&company_name=' . urlencode($nasPbDetails['company_name']) . '";';
        echo '</script>';
    } else {
        // Update the NAS PB details in the database
        $stmt = $pdo->prepare('UPDATE item_type_nas_pb SET 
            active = :active,
            pb_service_name = :pb_service_name,
            pb_service_from = :pb_service_from,
            pb_service_to_folder = :pb_service_to_folder,
            pb_service_schedule = :pb_service_schedule,
            pb_service_time = :pb_service_time,
            pb_service_retention = :pb_service_retention,
            pb_installed_pc = :pb_installed_pc,
            updated_time = NOW()
            WHERE item_type_nas_pb_id = :item_type_nas_pb_id');

        $success = $stmt->execute([
            ':active' => $active,
            ':pb_service_name' => $pbServiceName,
            ':pb_service_from' => $pbServiceFrom,
            ':pb_service_to_folder' => $pbServiceToFolder,
            ':pb_service_schedule' => $pbServiceSchedule,
            ':pb_service_time' => $pbServiceTime,
            ':pb_service_retention' => $pbServiceRetention,
            ':pb_installed_pc' => $pbInstalledPc,
            ':item_type_nas_pb_id' => $itemTypeNasPbId
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_nas_pb WHERE item_type_nas_pb_id = :item_type_nas_pb_id LIMIT 1');
            $stmt->execute([':item_type_nas_pb_id' => $itemTypeNasPbId]);
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in Active Backup Physical Server (Company Name: " . $companyName . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasPbDetails['debtor_code']) . '&company_name=' . urlencode($nasPbDetails['company_name']) . '";';
            echo '</script>';
        } else {
            // If update failed, show error message
            echo '<script type="text/javascript">';
            echo 'alert("Failed to update. Please try again.");';
            echo '</script>';
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit NAS Physical Server Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit NAS Physical Server Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="item_type_nas_id" value="<?= htmlspecialchars($itemTypeNasId) ?>">
                
                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $nasPbDetails['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>
            
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Active Backup Physical Server</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pb_service_name" id="pb_service_name" placeholder="Physical Backup Service Name" value="<?= htmlspecialchars($nasPbDetails['pb_service_name'] ?? '') ?>">
                                    <label for="pb_service_name">Physical Backup Service Name</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pb_service_from" id="pb_service_from" placeholder="Physical Backup Service From" value="<?= htmlspecialchars($nasPbDetails['pb_service_from'] ?? '') ?>">
                                    <label for="pb_service_from">Physical Backup Service From</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pb_service_to_folder" id="pb_service_to_folder" placeholder="Physical Backup Service To Folder" value="<?= htmlspecialchars($nasPbDetails['pb_service_to_folder'] ?? '') ?>">
                                    <label for="pb_service_to_folder">Physical Backup Service To Folder</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pb_service_schedule" id="pb_service_schedule" placeholder="Physical Backup Service Schedule" value="<?= htmlspecialchars($nasPbDetails['pb_service_schedule'] ?? '') ?>">
                                    <label for="pb_service_schedule">Physical Backup Service Schedule</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="time" class="form-control" name="pb_service_time" id="pb_service_time" placeholder="Physical Backup Service Time" value="<?= htmlspecialchars($nasPbDetails['pb_service_time'] ?? '') ?>">
                                    <label for="pb_service_time">Physical Backup Service Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pb_service_retention" id="pb_service_retention" placeholder="Physical Backup Service Retention" value="<?= htmlspecialchars($nasPbDetails['pb_service_retention'] ?? '') ?>">
                                    <label for="pb_service_retention">Physical Backup Service Retention</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <select class="form-select" name="pb_installed_pc" id="pb_installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($installedPcs as $pc): ?>
                                            <option value="<?= htmlspecialchars($pc) ?>" <?= $pc == $nasPbDetails['pb_installed_pc'] ? 'selected' : '' ?>><?= htmlspecialchars($pc) ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="pb_installed_pc">Physical Backup Installed PC</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

