<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if item_type_nas_sd_id is passed via URL
if (!isset($_GET['item_type_nas_sd_id'])) {
    echo "<p>No NAS SD ID provided.</p>";
    exit;
}

$itemTypeNasSdId = $_GET['item_type_nas_sd_id'];

// Fetch the NAS SD details based on item_type_nas_sd_id
$stmt = $pdo->prepare('SELECT * FROM item_type_nas_sd WHERE item_type_nas_sd_id = :item_type_nas_sd_id LIMIT 1');
$stmt->execute([':item_type_nas_sd_id' => $itemTypeNasSdId]);
$nasSdDetails = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$nasSdDetails) {
    echo "<p>No NAS SD details found with the provided ID.</p>";
    exit;
}

// Fetch the company name based on debtor_code
$companyName = 'Unknown Company'; // Default fallback
if ($nasSdDetails['debtor_code']) {
    try {
        $stmt = $pdo->prepare("SELECT company_name FROM company_info WHERE debtor_code = :debtor_code LIMIT 1");
        $stmt->execute([':debtor_code' => $nasSdDetails['debtor_code']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $companyName = $company['company_name'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs for the selected company based on debtor_code and company_name
$installedPcs = [];
if ($nasSdDetails['debtor_code'] && $nasSdDetails['company_name']) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $nasSdDetails['debtor_code'], ':company_name' => $nasSdDetails['company_name']]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Decrypt the password
$decryptedPassword = decryptPassword($nasSdDetails['sd_login_password'], 'your_secret_key');

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $sdLoginId = htmlspecialchars($_POST['sd_login_id']);
    $sdLoginPassword = htmlspecialchars($_POST['sd_login_password']);
    $sdBackupUrl = htmlspecialchars($_POST['sd_backup_url']);
    $sdServiceFrom = htmlspecialchars($_POST['sd_service_from']);
    $sdServiceToFolder = htmlspecialchars($_POST['sd_service_to_folder']);
    $sdServiceSchedule = htmlspecialchars($_POST['sd_service_schedule']);
    $sdServiceTime = htmlspecialchars($_POST['sd_service_time']);
    $sdInstalledPc = htmlspecialchars($_POST['sd_installed_pc']);
    $sdBackupMode = htmlspecialchars($_POST['sd_backup_mode']);

    // Encrypt the password before saving
    $encryptedPassword = encryptPassword($sdLoginPassword, 'your_secret_key');

    // Store the old data for comparison
    $oldData = $nasSdDetails;

    // Decrypt the old password for comparison
    $oldDecryptedPassword = decryptPassword($oldData['sd_login_password'], 'your_secret_key');

    // Check if any data has changed
    $dataChanged = false;
    if ($active != $oldData['active'] ||
        $sdLoginId != $oldData['sd_login_id'] ||
        $sdLoginPassword != $oldDecryptedPassword ||
        $sdBackupUrl != $oldData['sd_backup_url'] ||
        $sdServiceFrom != $oldData['sd_service_from'] ||
        $sdServiceToFolder != $oldData['sd_service_to_folder'] ||
        $sdServiceSchedule != $oldData['sd_service_schedule'] ||
        $sdServiceTime != $oldData['sd_service_time'] ||
        $sdInstalledPc != $oldData['sd_installed_pc'] ||
        $sdBackupMode != $oldData['sd_backup_mode']) {
        $dataChanged = true;
    }

    if (!$dataChanged) {
        // If no data changed, show alert and redirect back to view_nas_table.php
        echo '<script type="text/javascript">';
        echo 'alert("No data changed.");';
        echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasSdDetails['debtor_code']) . '&company_name=' . urlencode($nasSdDetails['company_name']) . '";';
        echo '</script>';
    } else {
        // Update the NAS SD details in the database
        $stmt = $pdo->prepare('UPDATE item_type_nas_sd SET 
            active = :active,
            sd_login_id = :sd_login_id,
            sd_login_password = :sd_login_password,
            sd_backup_url = :sd_backup_url,
            sd_service_from = :sd_service_from,
            sd_service_to_folder = :sd_service_to_folder,
            sd_service_schedule = :sd_service_schedule,
            sd_service_time = :sd_service_time,
            sd_installed_pc = :sd_installed_pc,
            sd_backup_mode = :sd_backup_mode,
            updated_time = NOW()
            WHERE item_type_nas_sd_id = :item_type_nas_sd_id');

        $success = $stmt->execute([
            ':active' => $active,
            ':sd_login_id' => $sdLoginId,
            ':sd_login_password' => $encryptedPassword, // Use the encrypted password
            ':sd_backup_url' => $sdBackupUrl,
            ':sd_service_from' => $sdServiceFrom,
            ':sd_service_to_folder' => $sdServiceToFolder,
            ':sd_service_schedule' => $sdServiceSchedule,
            ':sd_service_time' => $sdServiceTime,
            ':sd_installed_pc' => $sdInstalledPc,
            ':sd_backup_mode' => $sdBackupMode,
            ':item_type_nas_sd_id' => $itemTypeNasSdId
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_nas_sd WHERE item_type_nas_sd_id = :item_type_nas_sd_id LIMIT 1');
            $stmt->execute([':item_type_nas_sd_id' => $itemTypeNasSdId]);
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Decrypt the new password for logging
            $newDecryptedPassword = decryptPassword($newItem['sd_login_password'], 'your_secret_key');

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in Synology Drive (Company Name: " . $companyName . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time') {
                    $oldValue = ($key === 'sd_login_password') ? $oldDecryptedPassword : $value;
                    $newValue = ($key === 'sd_login_password') ? $newDecryptedPassword : $newItem[$key];

                    if ($newValue !== $oldValue) {
                        $logMessage .= "$key: $oldValue -> $newValue\n";
                    }
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasSdDetails['debtor_code']) . '&company_name=' . urlencode($nasSdDetails['company_name']) . '";';
            echo '</script>';
        } else {
            // If update failed, show error message
            echo '<script type="text/javascript">';
            echo 'alert("Failed to update. Please try again.");';
            echo '</script>';
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit NAS Synology Drive Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit NAS Synology Drive Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="item_type_nas_id" value="<?= htmlspecialchars($itemTypeNasId) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $nasSdDetails['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Active Backup Synology Drive</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_login_id" id="sd_login_id" placeholder="Synology Drive Login ID" value="<?= htmlspecialchars($nasSdDetails['sd_login_id'] ?? '') ?>">
                                    <label for="sd_login_id">Synology Drive Login ID</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_login_password" id="sd_login_password" placeholder="Synology Drive Login Password" value="<?= htmlspecialchars($decryptedPassword ?? '') ?>">
                                    <label for="sd_login_password">Synology Drive Login Password</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_backup_url" id="sd_backup_url" placeholder="Synology Drive Backup URL" value="<?= htmlspecialchars($nasSdDetails['sd_backup_url'] ?? '') ?>">
                                    <label for="sd_backup_url">Synology Drive Backup URL</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_service_from" id="sd_service_from" placeholder="Synology Drive Service From" value="<?= htmlspecialchars($nasSdDetails['sd_service_from'] ?? '') ?>">
                                    <label for="sd_service_from">Synology Drive Service From</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_service_to_folder" id="sd_service_to_folder" placeholder="Synology Drive Service To Folder" value="<?= htmlspecialchars($nasSdDetails['sd_service_to_folder'] ?? '') ?>">
                                    <label for="sd_service_to_folder">Synology Drive Service To Folder</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_service_schedule" id="sd_service_schedule" placeholder="Synology Drive Service Schedule Start Time" value="<?= htmlspecialchars($nasSdDetails['sd_service_schedule'] ?? '') ?>">
                                    <label for="sd_service_schedule">Synology Drive Service Schedule Start Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="time" class="form-control" name="sd_service_time" id="sd_service_time" placeholder="Synology Drive Backup Time" value="<?= htmlspecialchars($nasSdDetails['sd_service_time'] ?? '') ?>">
                                    <label for="sd_service_time">Synology Drive Backup Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <select class="form-select" name="sd_installed_pc" id="sd_installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($installedPcs as $pc): ?>
                                            <option value="<?= htmlspecialchars($pc) ?>" <?= $pc == $nasSdDetails['sd_installed_pc'] ? 'selected' : '' ?>><?= htmlspecialchars($pc) ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="sd_installed_pc">Synology Drive Installed PC</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <select class="form-select" name="sd_backup_mode" id="sd_backup_mode">
                                        <option value="continuous" <?= isset($nasSdDetails['sd_backup_mode']) && $nasSdDetails['sd_backup_mode'] == 'continuous' ? 'selected' : '' ?>>Continuous Backup</option>
                                        <option value="manual" <?= isset($nasSdDetails['sd_backup_mode']) && $nasSdDetails['sd_backup_mode'] == 'manual' ? 'selected' : '' ?>>Manual Backup</option>
                                        <option value="schedule" <?= isset($nasSdDetails['sd_backup_mode']) && $nasSdDetails['sd_backup_mode'] == 'schedule' ? 'selected' : '' ?>>Schedule Backup</option>
                                    </select>
                                    <label for="sd_backup_mode">Synology Drive Backup Mode</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

