<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_pos_hw_others_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_pos_hw_others_id'])) {
    echo "<p>No debtor code or POS Others ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$posOthersId = $_GET['item_type_pos_hw_others_id'];

// Fetch the POS Others details based on debtor_code and item_type_pos_hw_others_id
$stmt = $pdo->prepare('SELECT * FROM item_type_pos_hw_others WHERE debtor_code = :debtor_code AND item_type_pos_hw_others_id = :item_type_pos_hw_others_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_pos_hw_others_id' => $posOthersId]);
$posOthers = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$posOthers) {
    echo "<p>No POS Others found with the provided ID.</p>";
    exit;
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Validate and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0;
        $model = htmlspecialchars($_POST['model']);
        $item_of = htmlspecialchars($_POST['item_of']);
        $part_no = htmlspecialchars($_POST['part_no']);
        $serial_number = htmlspecialchars($_POST['serial_number']);
        $purchase_date = htmlspecialchars($_POST['purchase_date']);
        $warranty_expire_date = htmlspecialchars($_POST['warranty_expire_date']);
        $others = htmlspecialchars($_POST['others']);

        // Store the old data for logging
        $oldData = $posOthers;

        // Check if any changes were made
        $hasChanges = false;
        foreach ($oldData as $key => $value) {
            if (isset($_POST[$key]) && $_POST[$key] != $value) {
                $hasChanges = true;
                break;
            }
        }

        if (!$hasChanges) {
            // No changes were made, display alert and redirect back to view_pos_hardware_table.php
            echo '<script type="text/javascript">';
            echo 'alert("No changes made.");';
            echo 'window.location.href="view_pos_hardware_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
            exit;
        }

        // Update the POS Others in the database
        $stmt = $pdo->prepare('UPDATE item_type_pos_hw_others SET active = :active, model = :model, item_of = :item_of, part_no = :part_no, serial_number = :serial_number, purchase_date = :purchase_date, warranty_expire_date = :warranty_expire_date, others = :others WHERE debtor_code = :debtor_code AND item_type_pos_hw_others_id = :item_type_pos_hw_others_id');
        $success = $stmt->execute([
            ':active' => $active,
            ':model' => $model,
            ':item_of' => $item_of,
            ':part_no' => $part_no,
            ':serial_number' => $serial_number,
            ':purchase_date' => $purchase_date,
            ':warranty_expire_date' => $warranty_expire_date,
            ':others' => $others,
            ':debtor_code' => $debtorCode,
            ':item_type_pos_hw_others_id' => $posOthersId
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_pos_hw_others WHERE debtor_code = :debtor_code AND item_type_pos_hw_others_id = :item_type_pos_hw_others_id LIMIT 1');
            $stmt->execute([':debtor_code' => $debtorCode, ':item_type_pos_hw_others_id' => $posOthersId]);
            $newData = $stmt->fetch(PDO::FETCH_ASSOC);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in POS Others (Debtor Code: " . $debtorCode . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newData[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newData[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_pos_hardware_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            throw new Exception("Failed to update the POS Others details.");
        }
    } catch (Exception $e) {
        echo '<script type="text/javascript">';
        echo 'alert("' . $e->getMessage() . '");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit POS Others Details</title>
    <!-- Bootstrap 5.x CSS with Floating Labels -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit POS Others Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_pos_hw_others_id" value="<?= htmlspecialchars($posOthersId) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $posOthers['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Hardware Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Hardware Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="model" id="model" class="form-control" value="<?= htmlspecialchars($posOthers['model'] ?? '') ?>" placeholder="Model">
                                    <label for="model">Model</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="item_of" id="item_of" class="form-control" value="<?= htmlspecialchars($posOthers['item_of'] ?? '') ?>" placeholder="Item Of">
                                    <label for="item_of">Item Of</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="part_no" id="part_no" class="form-control" value="<?= htmlspecialchars($posOthers['part_no'] ?? '') ?>" placeholder="Part No">
                                    <label for="part_no">Part No</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="serial_number" id="serial_number" class="form-control" value="<?= htmlspecialchars($posOthers['serial_number'] ?? '') ?>" placeholder="Serial Number">
                                    <label for="serial_number">Serial Number</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Warranty Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Warranty Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="purchase_date" id="purchase_date" class="form-control" value="<?= htmlspecialchars($posOthers['purchase_date'] ?? '') ?>" placeholder="Purchase Date">
                                    <label for="purchase_date">Purchase Date</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="warranty_expire_date" id="warranty_expire_date" class="form-control" value="<?= htmlspecialchars($posOthers['warranty_expire_date'] ?? '') ?>" placeholder="Warranty Expire Date">
                                    <label for="warranty_expire_date">Warranty Expire Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea 
                                id="others" 
                                name="others" 
                                class="form-control" 
                                placeholder="Others" 
                                style="height: 200px; resize: vertical; overflow-y: hidden;"
                                oninput="this.style.height = ''; this.style.height = this.scrollHeight + 'px';"
                            ><?= htmlspecialchars($posOthers['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS with Floating Labels -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

