<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_pos_hw_palm_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_pos_hw_palm_id'])) {
    echo "<p>No debtor code or POS Palm ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$posPalmId = $_GET['item_type_pos_hw_palm_id'];

// Fetch the POS Palm details based on debtor_code and item_type_pos_hw_palm_id
$stmt = $pdo->prepare('SELECT * FROM item_type_pos_hw_palm WHERE debtor_code = :debtor_code AND item_type_pos_hw_palm_id = :item_type_pos_hw_palm_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_pos_hw_palm_id' => $posPalmId]);
$posPalm = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$posPalm) {
    echo "<p>No POS Palm found with the provided ID.</p>";
    exit;
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Validate and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0;
        $installed_ac_software = htmlspecialchars($_POST['installed_ac_software']);
        $harddisk_space = htmlspecialchars($_POST['harddisk_space']);
        $ram_gb = htmlspecialchars($_POST['ram_gb']);
        $os_version = htmlspecialchars($_POST['os_version']);
        $part_no = htmlspecialchars($_POST['part_no']);
        $serial_number = htmlspecialchars($_POST['serial_number']);
        $purchase_date = htmlspecialchars($_POST['purchase_date']);
        $warranty_expire_date = htmlspecialchars($_POST['warranty_expire_date']);
        $others = htmlspecialchars($_POST['others']);

        // Store the old data for logging
        $oldData = $posPalm;

        // Check if any changes were made
        $hasChanges = false;
        foreach ($oldData as $key => $value) {
            if (isset($_POST[$key]) && $_POST[$key] != $value) {
                $hasChanges = true;
                break;
            }
        }

        if (!$hasChanges) {
            // No changes were made, display alert and redirect back to view_pos_hardware_table.php
            echo '<script type="text/javascript">';
            echo 'alert("No changes made.");';
            echo 'window.location.href="view_pos_hardware_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
            exit;
        }

        // Update the POS Palm in the database
        $stmt = $pdo->prepare('UPDATE item_type_pos_hw_palm SET active = :active, installed_ac_software = :installed_ac_software, harddisk_space = :harddisk_space, ram_gb = :ram_gb, os_version = :os_version, part_no = :part_no, serial_number = :serial_number, purchase_date = :purchase_date, warranty_expire_date = :warranty_expire_date, others = :others WHERE debtor_code = :debtor_code AND item_type_pos_hw_palm_id = :item_type_pos_hw_palm_id');
        $success = $stmt->execute([
            ':active' => $active,
            ':installed_ac_software' => $installed_ac_software,
            ':harddisk_space' => $harddisk_space,
            ':ram_gb' => $ram_gb,
            ':os_version' => $os_version,
            ':part_no' => $part_no,
            ':serial_number' => $serial_number,
            ':purchase_date' => $purchase_date,
            ':warranty_expire_date' => $warranty_expire_date,
            ':others' => $others,
            ':debtor_code' => $debtorCode,
            ':item_type_pos_hw_palm_id' => $posPalmId
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_pos_hw_palm WHERE debtor_code = :debtor_code AND item_type_pos_hw_palm_id = :item_type_pos_hw_palm_id LIMIT 1');
            $stmt->execute([':debtor_code' => $debtorCode, ':item_type_pos_hw_palm_id' => $posPalmId]);
            $newData = $stmt->fetch(PDO::FETCH_ASSOC);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in POS Palm (Debtor Code: " . $debtorCode . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newData[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newData[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_pos_hardware_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            throw new Exception("Failed to update the POS Palm details.");
        }
    } catch (Exception $e) {
        echo '<script type="text/javascript">';
        echo 'alert("' . $e->getMessage() . '");';
        echo '</script>';
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit POS Palm Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit POS Palm Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $posPalm['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Software and Hardware Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Software and Hardware Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="installed_ac_software" id="installed_ac_software" class="form-control" placeholder="Installed AC Software" value="<?= htmlspecialchars($posPalm['installed_ac_software'] ?? '') ?>">
                                    <label for="installed_ac_software">Installed AC Software</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="harddisk_space" id="harddisk_space" class="form-control" placeholder="Hard Disk Space" value="<?= htmlspecialchars($posPalm['harddisk_space'] ?? '') ?>">
                                    <label for="harddisk_space">Hard Disk Space</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="ram_gb" id="ram_gb" class="form-control" placeholder="RAM GB" value="<?= htmlspecialchars($posPalm['ram_gb'] ?? '') ?>">
                                    <label for="ram_gb">RAM GB</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="os_version" id="os_version" class="form-control" placeholder="OS Version" value="<?= htmlspecialchars($posPalm['os_version'] ?? '') ?>">
                                    <label for="os_version">OS Version</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Hardware Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Hardware Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="part_no" id="part_no" class="form-control" placeholder="Part No" value="<?= htmlspecialchars($posPalm['part_no'] ?? '') ?>">
                                    <label for="part_no">Part No</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="serial_number" id="serial_number" class="form-control" placeholder="Serial Number" value="<?= htmlspecialchars($posPalm['serial_number'] ?? '') ?>">
                                    <label for="serial_number">Serial Number</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Warranty Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Warranty Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="purchase_date" id="purchase_date" class="form-control" placeholder="Purchase Date" value="<?= htmlspecialchars($posPalm['purchase_date'] ?? '') ?>">
                                    <label for="purchase_date">Purchase Date</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="warranty_expire_date" id="warranty_expire_date" class="form-control" placeholder="Warranty Expire Date" value="<?= htmlspecialchars($posPalm['warranty_expire_date'] ?? '') ?>">
                                    <label for="warranty_expire_date">Warranty Expire Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"><?= htmlspecialchars($posPalm['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

