<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Encryption key (must match the key used in encrypt.php)
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Check if debtor_code and item_type_sw_microsoft_nr_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_sw_microsoft_nr_id'])) {
    echo "<p>No debtor code or Microsoft NR ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$microsoftNrId = $_GET['item_type_sw_microsoft_nr_id'];

try {
    // Fetch the Microsoft NR details based on debtor_code and item_type_sw_microsoft_nr_id
    $stmt = $pdo->prepare('SELECT * FROM item_type_sw_microsoft_nr WHERE debtor_code = :debtor_code AND item_type_sw_microsoft_nr_id = :item_type_sw_microsoft_nr_id LIMIT 1');
    $stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_microsoft_nr_id' => $microsoftNrId]);
    $microsoftNr = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$microsoftNr) {
        throw new Exception("No Microsoft NR found with the provided ID.");
    }

    // Decrypt the password field for display and comparison
    $microsoftNr['password'] = decryptPassword($microsoftNr['password'], $encryptionKey);

    // Fetch the computer names based on debtor_code
    $computerNames = [];
    if (!empty($debtorCode)) {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code");
        $stmt->execute([':debtor_code' => $debtorCode]);
        $computerNames = $stmt->fetchAll(PDO::FETCH_COLUMN);
    }
} catch (Exception $e) {
    echo "<p>Error: " . $e->getMessage() . "</p>";
    exit;
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Validate and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0;
        $installed_pc = htmlspecialchars($_POST['installed_pc']);
        $login = htmlspecialchars($_POST['login']);
        $password = htmlspecialchars($_POST['password']);
        $software_name = htmlspecialchars($_POST['software_name']);
        $software_version = htmlspecialchars($_POST['software_version']);
        $authenticator = htmlspecialchars($_POST['authenticator']);
        $license = htmlspecialchars($_POST['license']);
        $others = htmlspecialchars($_POST['others']);

        // Store the old data for logging (decrypted password included)
        $oldData = $microsoftNr;

        // Check if any changes were made
        $hasChanges = false;
        if ($active != $oldData['active']) $hasChanges = true;
        if ($installed_pc != $oldData['installed_pc']) $hasChanges = true;
        if ($login != $oldData['login']) $hasChanges = true;
        if ($password != $oldData['password']) $hasChanges = true;
        if ($software_name != $oldData['software_name']) $hasChanges = true;
        if ($software_version != $oldData['software_version']) $hasChanges = true;
        if ($authenticator != $oldData['authenticator']) $hasChanges = true;
        if ($license != $oldData['license']) $hasChanges = true;
        if ($others != $oldData['others']) $hasChanges = true;

        if (!$hasChanges) {
            // No changes were made, display alert and redirect back to view_software_table.php
            echo '<script type="text/javascript">';
            echo 'alert("No changes made.");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
            exit;
        }

        // Encrypt the password before storing it in the database
        $encryptedPassword = encryptPassword($password, $encryptionKey);

        // Update the Microsoft NR in the database
        $stmt = $pdo->prepare('UPDATE item_type_sw_microsoft_nr SET active = :active, installed_pc = :installed_pc, login = :login, password = :password, software_name = :software_name, software_version = :software_version, authenticator = :authenticator, license = :license, updated_time = NOW(), others = :others WHERE debtor_code = :debtor_code AND item_type_sw_microsoft_nr_id = :item_type_sw_microsoft_nr_id');
        $success = $stmt->execute([
            ':active' => $active,
            ':installed_pc' => $installed_pc,
            ':login' => $login,
            ':password' => $encryptedPassword, // Encrypted password
            ':software_name' => $software_name,
            ':software_version' => $software_version,
            ':authenticator' => $authenticator,
            ':license' => $license,
            ':others' => $others,
            ':debtor_code' => $debtorCode,
            ':item_type_sw_microsoft_nr_id' => $microsoftNrId
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_sw_microsoft_nr WHERE debtor_code = :debtor_code AND item_type_sw_microsoft_nr_id = :item_type_sw_microsoft_nr_id LIMIT 1');
            $stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_microsoft_nr_id' => $microsoftNrId]);
            $newData = $stmt->fetch(PDO::FETCH_ASSOC);

            // Decrypt the password field for logging
            $newData['password'] = decryptPassword($newData['password'], $encryptionKey);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in Microsoft NR (Debtor Code: " . $debtorCode . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newData[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newData[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            throw new Exception("Failed to update the Microsoft NR details.");
        }
    } catch (Exception $e) {
        echo '<script type="text/javascript">';
        echo 'alert("' . $e->getMessage() . '");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Microsoft NR Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Microsoft (No Renewal) Details</h1>
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_sw_id" value="<?= htmlspecialchars($microsoftNrId) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $microsoftNr['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">For Email Activation Only</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login" id="login" class="form-control" placeholder="Login" value="<?= htmlspecialchars($microsoftNr['login'] ?? '') ?>">
                                    <label for="login">Login</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="password" id="password" class="form-control" placeholder="Password" value="<?= htmlspecialchars($microsoftNr['password'] ?? '') ?>">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="authenticator" id="authenticator" class="form-control" placeholder="Authenticator mobile name" value="<?= htmlspecialchars($microsoftNr['authenticator'] ?? '') ?>">
                                    <label for="authenticator">Authenticator mobile name</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group">
                            <label for="installed_pc">Installed PC</label>
                            <select class="form-control" name="installed_pc" id="installed_pc">
                                <option value="">Select Installed PC</option>
                                <?php foreach ($computerNames as $option): ?>
                                    <option value="<?= htmlspecialchars($option) ?>" <?= $option == $microsoftNr['installed_pc'] ? 'selected' : '' ?>><?= htmlspecialchars($option) ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Software Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="software_name" id="software_name" class="form-control" placeholder="Software Name" value="<?= htmlspecialchars($microsoftNr['software_name'] ?? '') ?>">
                                    <label for="software_name">Software Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="software_version" id="software_version" class="form-control" placeholder="Software Version" value="<?= htmlspecialchars($microsoftNr['software_version'] ?? '') ?>">
                                    <label for="software_version">Software Version</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="license" id="license" class="form-control" placeholder="License PID" value="<?= htmlspecialchars($microsoftNr['license'] ?? '') ?>">
                                    <label for="license">License PID</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"><?= htmlspecialchars($microsoftNr['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: "Select Installed PC",
            closeOnSelect: true, // Ensure it closes after selecting one option
        });
    });
</script>
</body>
</html>

