<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Encryption key (must match the key used in encrypt.php)
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Check if debtor_code and item_type_sw_o365_client_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_sw_o365_client_id'])) {
    echo "<p>No debtor code or O365 ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$o365Id = $_GET['item_type_sw_o365_client_id'];

// Fetch the O365 details based on debtor_code and item_type_sw_o365_client_id
$stmt = $pdo->prepare('SELECT * FROM item_type_sw_o365_client WHERE debtor_code = :debtor_code AND item_type_sw_o365_client_id = :item_type_sw_o365_client_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_o365_client_id' => $o365Id]);
$o365 = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$o365) {
    echo "<p>No O365 found with the provided ID.</p>";
    exit;
}

// Decrypt the client_account_password
if (!empty($o365['client_account_password'])) {
    $decryptedPassword = decryptPassword($o365['client_account_password'], $encryptionKey);
    if ($decryptedPassword !== null) {
        $o365['client_account_password'] = $decryptedPassword; // Replace encrypted password with decrypted one
    } else {
        echo "<p>Failed to decrypt the password. Please check the decryption key or the encrypted data.</p>";
        exit;
    }
}

// Fetch the license data
$licenses = [];
if (!empty($debtorCode) && !empty($o365['company_name'])) {
    $stmt = $pdo->prepare("SELECT master_account_id FROM item_type_sw_o365_master WHERE item_type_sw_group_name = 'Office 365 Master Account' AND debtor_code = :debtor_code AND company_name = :company_name");
    $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $o365['company_name']]);
    $licenses = $stmt->fetchAll(PDO::FETCH_COLUMN);
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Validate and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0;
        $client_account_id = htmlspecialchars($_POST['client_account_id']);
        $client_account_password = htmlspecialchars($_POST['client_account_password']);
        $license = htmlspecialchars($_POST['license']);
        $authenticator = htmlspecialchars($_POST['authenticator']);
        $others = htmlspecialchars($_POST['others']);

        // Encrypt the client_account_password before saving to the database
        $encryptedPassword = encryptPassword($client_account_password, $encryptionKey);

        // Store the old data for logging
        $oldData = $o365;

        // Check if any changes were made
        $hasChanges = false;
        if ($active != $oldData['active']) $hasChanges = true;
        if ($client_account_id != $oldData['client_account_id']) $hasChanges = true;
        if ($client_account_password != $oldData['client_account_password']) $hasChanges = true;
        if ($license != $oldData['license']) $hasChanges = true;
        if ($authenticator != $oldData['authenticator']) $hasChanges = true;
        if ($others != $oldData['others']) $hasChanges = true;

        if (!$hasChanges) {
            // No changes were made, display alert and redirect back to view_software_table.php
            echo '<script type="text/javascript">';
            echo 'alert("No changes made.");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
            exit;
        }

        // Update the O365 in the database
        $stmt = $pdo->prepare('UPDATE item_type_sw_o365_client SET active = :active, client_account_id = :client_account_id, client_account_password = :client_account_password, license = :license, authenticator = :authenticator, others = :others, updated_time = NOW() WHERE debtor_code = :debtor_code AND item_type_sw_o365_client_id = :item_type_sw_o365_client_id');
        $success = $stmt->execute([
            ':active' => $active,
            ':client_account_id' => $client_account_id,
            ':client_account_password' => $encryptedPassword, // Encrypted password
            ':license' => $license,
            ':authenticator' => $authenticator,
            ':others' => $others,
            ':debtor_code' => $debtorCode,
            ':item_type_sw_o365_client_id' => $o365Id
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_sw_o365_client WHERE debtor_code = :debtor_code AND item_type_sw_o365_client_id = :item_type_sw_o365_client_id LIMIT 1');
            $stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_o365_client_id' => $o365Id]);
            $newData = $stmt->fetch(PDO::FETCH_ASSOC);

            // Decrypt sensitive fields for logging
            $newData['client_account_password'] = decryptPassword($newData['client_account_password'], $encryptionKey);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in O365 Client (Debtor Code: " . $debtorCode . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newData[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newData[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            throw new Exception("Failed to update the O365 details.");
        }
    } catch (Exception $e) {
        echo '<script type="text/javascript">';
        echo 'alert("' . $e->getMessage() . '");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit O365 Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit O365 Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_sw_id" value="<?= htmlspecialchars($o365Id) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= isset($o365['active']) && $o365['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">License</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="license">License</label>
                                    <select class="form-select" id="license" name="license" data-placeholder="Choose a license">
                                        <option value="">Please select a license</option>
                                        <?php foreach ($licenses as $license): ?>
                                            <option value="<?php echo htmlspecialchars($license); ?>" <?= $o365['license'] == $license ? 'selected' : '' ?>><?php echo htmlspecialchars($license); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Account Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <!-- Left column -->
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="client_account_id" id="client_account_id" class="form-control" placeholder="Client Account ID" value="<?= htmlspecialchars($o365['client_account_id'] ?? '') ?>">
                                    <label for="client_account_id">Client Account ID</label>
                                </div>
                            </div>
                            <!-- Right column -->
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="client_account_password" id="client_account_password" class="form-control" placeholder="Client Account Password" value="<?= htmlspecialchars($o365['client_account_password'] ?? '') ?>">
                                    <label for="client_account_password">Client Account Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Authenticator and Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="authenticator" id="authenticator" class="form-control" placeholder="Authenticator Mobile Name (For Office Use)" value="<?= htmlspecialchars($o365['authenticator'] ?? '') ?>">
                                    <label for="authenticator">Authenticator Mobile Name (For Office Use)</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-floating mb-3">
                                    <textarea id="others" name="others" class="form-control" placeholder="Others"><?= htmlspecialchars($o365['others'] ?? '') ?></textarea>
                                    <label for="others">Others</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#license').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: "Choose a license",
            closeOnSelect: true,
        });
    });
</script>
</body>
</html>

