<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Encryption key (must match the key used in encrypt.php)
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Check if debtor_code and item_type_sw_o365_master_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_sw_o365_master_id'])) {
    echo "<p>No debtor code or O365 ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$o365Id = $_GET['item_type_sw_o365_master_id'];

// Fetch the O365 details based on debtor_code and item_type_sw_o365_master_id
$stmt = $pdo->prepare('SELECT * FROM item_type_sw_o365_master WHERE debtor_code = :debtor_code AND item_type_sw_o365_master_id = :item_type_sw_o365_master_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_o365_master_id' => $o365Id]);
$o365 = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$o365) {
    echo "<p>No O365 found with the provided ID.</p>";
    exit;
}

// Decrypt sensitive fields for display and comparison
$o365['master_account_password'] = decryptPassword($o365['master_account_password'], $encryptionKey);
$o365['password'] = decryptPassword($o365['password'], $encryptionKey);

// Fetch the list of installed PCs from the database
$installedPcs = [];
try {
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
    $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $o365['company_name']]);
    $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Validate and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0;
        $installed_pc = htmlspecialchars($_POST['installed_pc']);
        $master_account_id = htmlspecialchars($_POST['master_account_id']);
        $master_account_password = htmlspecialchars($_POST['master_account_password']);
        $license = htmlspecialchars($_POST['license']);
        $login = htmlspecialchars($_POST['login']);
        $password = htmlspecialchars($_POST['password']);
        $authenticator = htmlspecialchars($_POST['authenticator']);
        $others = htmlspecialchars($_POST['others']);

        // Encrypt sensitive fields before storing in the database
        $encryptedMasterAccountPassword = encryptPassword($master_account_password, $encryptionKey);
        $encryptedPassword = encryptPassword($password, $encryptionKey);

        // Store the old data for logging
        $oldData = $o365;

        // Check if any changes were made
        $hasChanges = false;
        if ($active != $oldData['active']) $hasChanges = true;
        if ($installed_pc != $oldData['installed_pc']) $hasChanges = true;
        if ($master_account_id != $oldData['master_account_id']) $hasChanges = true;
        if ($master_account_password != $oldData['master_account_password']) $hasChanges = true;
        if ($license != $oldData['license']) $hasChanges = true;
        if ($login != $oldData['login']) $hasChanges = true;
        if ($password != $oldData['password']) $hasChanges = true;
        if ($authenticator != $oldData['authenticator']) $hasChanges = true;
        if ($others != $oldData['others']) $hasChanges = true;

        if (!$hasChanges) {
            // No changes were made, display alert and redirect back to view_software_table.php
            echo '<script type="text/javascript">';
            echo 'alert("No changes made.");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
            exit;
        }

        // Update the O365 in the database
        $stmt = $pdo->prepare('UPDATE item_type_sw_o365_master SET active = :active, installed_pc = :installed_pc, master_account_id = :master_account_id, master_account_password = :master_account_password, license = :license, login = :login, password = :password, authenticator = :authenticator, others = :others, updated_time = NOW() WHERE debtor_code = :debtor_code AND item_type_sw_o365_master_id = :item_type_sw_o365_master_id');
        $success = $stmt->execute([
            ':active' => $active,
            ':installed_pc' => $installed_pc,
            ':master_account_id' => $master_account_id,
            ':master_account_password' => $encryptedMasterAccountPassword, // Encrypted password
            ':license' => $license,
            ':login' => $login,
            ':password' => $encryptedPassword, // Encrypted password
            ':authenticator' => $authenticator,
            ':others' => $others,
            ':debtor_code' => $debtorCode,
            ':item_type_sw_o365_master_id' => $o365Id
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_sw_o365_master WHERE debtor_code = :debtor_code AND item_type_sw_o365_master_id = :item_type_sw_o365_master_id LIMIT 1');
            $stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_o365_master_id' => $o365Id]);
            $newData = $stmt->fetch(PDO::FETCH_ASSOC);

            // Decrypt sensitive fields for logging
            $newData['master_account_password'] = decryptPassword($newData['master_account_password'], $encryptionKey);
            $newData['password'] = decryptPassword($newData['password'], $encryptionKey);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in O365 Master (Debtor Code: " . $debtorCode . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newData[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newData[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            throw new Exception("Failed to update the O365 details.");
        }
    } catch (Exception $e) {
        echo '<script type="text/javascript">';
        echo 'alert("' . $e->getMessage() . '");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit O365 Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit O365 Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_sw_id" value="<?= htmlspecialchars($o365Id) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $o365['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Account Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="master_account_id" id="master_account_id" class="form-control" placeholder="Master Account ID" value="<?= htmlspecialchars($o365['master_account_id'] ?? '') ?>">
                                    <label for="master_account_id">Master Account ID</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="master_account_password" id="master_account_password" class="form-control" placeholder="Master Account Password" value="<?= htmlspecialchars($o365['master_account_password'] ?? '') ?>">
                                    <label for="master_account_password">Master Account Password</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="license" id="license" class="form-control" placeholder="License" value="<?= htmlspecialchars($o365['license'] ?? '') ?>">
                                    <label for="license">License</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login" id="login" class="form-control" placeholder="Login" value="<?= htmlspecialchars($o365['login'] ?? '') ?>">
                                    <label for="login">Login</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="password" id="password" class="form-control" placeholder="Password" value="<?= htmlspecialchars($o365['password'] ?? '') ?>">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="authenticator" id="authenticator" class="form-control" placeholder="Authenticator Mobile Name (For Office Use)" value="<?= htmlspecialchars($o365['authenticator'] ?? '') ?>">
                                    <label for="authenticator">Authenticator Mobile Name (For Office Use)</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"><?= htmlspecialchars($o365['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Installed PC</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group">
                            <label for="installed_pc">Installed PC</label>
                            <select class="form-control" name="installed_pc" id="installed_pc">
                                <option value="">Select Installed PC</option>
                                <?php foreach ($installedPcs as $option): ?>
                                    <option value="<?php echo htmlspecialchars($option); ?>" <?= $o365['installed_pc'] == $option ? 'selected' : '' ?>><?php echo htmlspecialchars($option); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: "Select Installed PC",
            closeOnSelect: true, // Ensure it closes after selecting one option
        });
    });
</script>
</body>
</html>

