<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database

// Handle delete request
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['delete'])) {
    $item_code_id = $_POST['item_code_id'];

    if (!empty($item_code_id)) {
        try {
            // Prepare and execute the SQL statement to delete the record
            $stmt = $pdo->prepare("DELETE FROM item_code WHERE item_code_id = :item_code_id");
            $stmt->bindParam(':item_code_id', $item_code_id, PDO::PARAM_INT);
            $stmt->execute();

            // Redirect with success message
            echo "<script>alert('Record deleted successfully!'); window.location.href = '/crm/public/stock_item/view_stock_item.php';</script>";
        } catch (PDOException $e) {
            error_log('Database delete error: ' . $e->getMessage());
            echo "<script>alert('Failed to delete record. Please try again.'); window.location.href = '/crm/public/stock_item/view_stock_item.php';</script>";
        }
    } else {
        echo "<script>alert('Invalid request.'); window.location.href = '/crm/public/stock_item/view_stock_item.php';</script>";
    }
}

// Fetch data based on selected item type, function note filter, and active status
$item_type_filter = $_GET['item_type'] ?? '';
$function_note_filter = $_GET['function_note'] ?? '';
$active_filter = $_GET['active'] ?? '';
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$items_per_page = 20;

$search_query = "SELECT ic.*, ic.active, fn.id AS function_id, fn.function_name, fn.function_description, fn.function_photo 
                 FROM item_code ic
                 LEFT JOIN function_notes fn ON ic.item_code_id = fn.item_code_id
                 WHERE 1=1";

$params = array();

if (!empty($item_type_filter)) {
    $search_query .= " AND ic.item_group = :item_type";
    $params[':item_type'] = $item_type_filter;
}

if (!empty($function_note_filter)) {
    if ($function_note_filter == 'has_function_note') {
        $search_query .= " AND fn.id IS NOT NULL";
    } elseif ($function_note_filter == 'no_function_note') {
        $search_query .= " AND fn.id IS NULL";
    }
}

if ($active_filter !== '') {
    $search_query .= " AND ic.active = :active";
    $params[':active'] = $active_filter;
}

error_log('SQL Query: ' . $search_query); // Debugging statement

try {
    // Prepare and execute the SQL statement to fetch data based on filters
    $stmt = $pdo->prepare($search_query);
    foreach ($params as $key => $value) {
        $stmt->bindValue($key, $value);
    }
    $stmt->execute();
    $item_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Calculate total number of items and pages
    $total_items = count($item_data);
    $total_pages = ceil($total_items / $items_per_page);

    // Determine the offset
    $offset = ($page - 1) * $items_per_page;

    // Fetch only the items for the current page
    $stmt = $pdo->prepare($search_query . " LIMIT :offset, :items_per_page");
    foreach ($params as $key => $value) {
        $stmt->bindValue($key, $value);
    }
    $stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
    $stmt->bindParam(':items_per_page', $items_per_page, PDO::PARAM_INT);
    $stmt->execute();
    $item_data = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    error_log('Database fetch error: ' . $e->getMessage());
    echo "<p>Error fetching data. Please try again later.</p>";
    exit;
}

// Group function notes by item_code_id
$grouped_functions = [];
foreach ($item_data as $row) {
    $item_code_id = $row['item_code_id'];
    if (!isset($grouped_functions[$item_code_id])) {
        $grouped_functions[$item_code_id] = [
            'item_code_id' => $row['item_code_id'],
            'item_name' => $row['item_name'],
            'active' => $row['active'],
            'item_group' => $row['item_group'],
            'functions' => []
        ];
    }
    if (!empty($row['function_name'])) {
        $grouped_functions[$item_code_id]['functions'][] = [
            'function_name' => $row['function_name'],
            'function_description' => $row['function_description'],
            'function_photo' => $row['function_photo']
        ];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.7.2/font/bootstrap-icons.css" rel="stylesheet">
    <title>View Item Code</title>
    <style>
        .no-results {
            display: none;
            text-align: center;
            color: red;
            font-weight: bold;
        }
        .active-icon {
            color: green;
        }
        .inactive-icon {
            color: red;
        }
        .table th {
            cursor: pointer;
        }
        .table-hover tbody tr:hover {
            background-color: #f5f5f5;
        }
        .function-details {
            display: none;
            background-color: #f9f9f9;
            padding: 15px;
            border-radius: 5px;
            margin-top: 10px;
        }
        .expand-btn {
            cursor: pointer;
        }
        .item-group-badge {
            font-size: 0.8em;
            padding: 0.3em 0.6em;
            border-radius: 10px;
            font-weight: bold;
        }
        .item-group-Goods { background-color: #d4edda; color: #155724; }
        .item-group-Licenses { background-color: #cce5ff; color: #004085; }
        .item-group-Subscriptions { background-color: #fff3cd; color: #856404; }
    </style>
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h2 class="mb-0">View Stock Item</h2>
        </div>
        <div class="card-body">
            <!-- Filters Section -->
            <div class="row mb-4">
                <div class="col-md-3">
                    <label for="itemTypeFilter" class="form-label">Filter by Item Type:</label>
                    <select id="itemTypeFilter" class="form-control" onchange="applyFilters()">
                        <option value="">All</option>
                        <option value="Goods" <?php echo ($item_type_filter == 'Goods') ? 'selected' : ''; ?>>Goods</option>
                        <option value="Licenses" <?php echo ($item_type_filter == 'Licenses') ? 'selected' : ''; ?>>Licenses</option>
                        <option value="Subscriptions" <?php echo ($item_type_filter == 'Subscriptions') ? 'selected' : ''; ?>>Subscriptions</option>
                    </select>
                </div>
                <div class="col-md-3">
                    <label for="functionNoteFilter" class="form-label">Filter by Function Note:</label>
                    <select id="functionNoteFilter" class="form-control" onchange="applyFilters()">
                        <option value="">All</option>
                        <option value="has_function_note" <?php echo ($function_note_filter == 'has_function_note') ? 'selected' : ''; ?>>Has Function Note</option>
                        <option value="no_function_note" <?php echo ($function_note_filter == 'no_function_note') ? 'selected' : ''; ?>>No Function Note</option>
                    </select>
                </div>
                <div class="col-md-3">
                    <label for="activeFilter" class="form-label">Filter by Active Status:</label>
                    <select id="activeFilter" class="form-control" onchange="applyFilters()">
                        <option value="">All</option>
                        <option value="1" <?php echo ($active_filter === '1') ? 'selected' : ''; ?>>Active</option>
                        <option value="0" <?php echo ($active_filter === '0') ? 'selected' : ''; ?>>Inactive</option>
                    </select>
                </div>
                <div class="col-md-3">
                    <label for="searchBar" class="form-label">Search Item Name:</label>
                    <input type="text" id="searchBar" class="form-control" placeholder="Search Item Name...">
                </div>
            </div>

            <!-- Reset Button -->
            <div class="mb-4 text-end">
                <button id="resetFilters" class="btn btn-outline-secondary"><i class="bi bi-arrow-counterclockwise"></i></button>
            </div>

            <!-- No results message -->
            <p id="noResults" class="no-results">No matching records found</p>

            <!-- Table -->
            <div class="table-responsive">
                <table class="table table-striped table-hover">
                    <thead>
                        <tr>
                            <th onclick="sortTable(0)">Active <i class="bi bi-arrow-down-up"></i></th>
                            <th onclick="sortTable(1)">Item Name <i class="bi bi-arrow-down-up"></i></th>
                            <th onclick="sortTable(2)">Item Group <i class="bi bi-arrow-down-up"></i></th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody id="tableBody">
                        <?php if (empty($grouped_functions)): ?>
                            <tr>
                                <td colspan="4" class="text-center">No records found</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($grouped_functions as $item_code_id => $item_data): ?>
                                <tr>
                                    <td>
                                        <?php if ($item_data['active'] == 1): ?>
                                            <i class="bi bi-check-circle-fill active-icon" title="Active"></i>
                                        <?php else: ?>
                                            <i class="bi bi-x-circle-fill inactive-icon" title="Inactive"></i>
                                        <?php endif; ?>
                                    </td>
                                    <td class="item-name">
                                        <?php echo $item_data['item_name']; ?>
                                        <?php if (!empty($item_data['functions'])): ?>
                                            <i class="bi bi-caret-down-fill expand-btn" onclick="toggleFunctionDetails(<?php echo $item_code_id; ?>)"></i>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <span class="item-group-badge item-group-<?php echo $item_data['item_group']; ?>">
                                            <?php echo $item_data['item_group']; ?>
                                        </span>
                                    </td>
                                    <td>
                                        <?php if (!empty($item_data['functions'])): ?>
                                            <a href="/crm/public/item_function/edit_function_note.php?item_code_id=<?php echo $item_data['item_code_id']; ?>" class="btn btn-primary btn-sm">Edit Function</a>
                                        <?php else: ?>
                                            <a href="/crm/public/item_function/add_function_note.php?item_code_id=<?php echo $item_data['item_code_id']; ?>" class="btn btn-success btn-sm">Add Function</a>
                                        <?php endif; ?>

                                        <a href="/crm/public/stock_item/edit_stock_item.php?item_code_id=<?php echo $item_data['item_code_id']; ?>" class="btn btn-primary btn-sm">Edit</a>
                                    </td>
                                </tr>
                                <?php if (!empty($item_data['functions'])): ?>
                                    <tr>
                                        <td colspan="4" class="function-details" id="function-<?php echo $item_code_id; ?>">
                                            <h5>Function Details:</h5>
                                            <?php foreach ($item_data['functions'] as $function): ?>
                                                <div class="mb-3">
                                                    <strong>Name:</strong> <?php echo $function['function_name']; ?><br>
                                                    <strong>Description:</strong> <?php echo $function['function_description']; ?><br>
                                                    <?php if (!empty($function['function_photo'])): ?>
                                                        <img src="<?php echo $function['function_photo']; ?>" alt="Function Photo" class="img-thumbnail mt-2" style="max-width: 200px;">
                                                    <?php endif; ?>
                                                </div>
                                            <?php endforeach; ?>
                                        </td>
                                    </tr>
                                <?php endif; ?>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- Pagination -->
            <nav aria-label="Page navigation">
                <ul class="pagination justify-content-center">
                    <?php
                    // Determine the range of pages to show
                    $start_page = max(1, $page - 5);
                    $end_page = min($total_pages, $page + 4);

                    // Adjust the range to always show 10 pages if possible
                    if ($end_page - $start_page < 9) {
                        if ($start_page == 1) {
                            $end_page = min($total_pages, $start_page + 9);
                        } else {
                            $start_page = max(1, $end_page - 9);
                        }
                    }

                    // Previous button
                    if ($page > 1) {
                        echo '<li class="page-item"><a class="page-link" href="?page=' . ($page - 1) . '&item_type=' . $item_type_filter . '&function_note=' . $function_note_filter . '&active=' . $active_filter . '">&laquo; Previous</a></li>';
                    } else {
                        echo '<li class="page-item disabled"><span class="page-link">&laquo;</span></li>';
                    }

                    // Page number links
                    for ($i = $start_page; $i <= $end_page; $i++) {
                        echo '<li class="page-item ' . ($i == $page ? 'active' : '') . '">';
                        echo '<a class="page-link" href="?page=' . $i . '&item_type=' . $item_type_filter . '&function_note=' . $function_note_filter . '&active=' . $active_filter . '">' . $i . '</a>';
                        echo '</li>';
                    }

                    // Next button
                    if ($page < $total_pages) {
                        echo '<li class="page-item"><a class="page-link" href="?page=' . ($page + 1) . '&item_type=' . $item_type_filter . '&function_note=' . $function_note_filter . '&active=' . $active_filter . '">Next &raquo;</a></li>';
                    } else {
                        echo '<li class="page-item disabled"><span class="page-link">&raquo;</span></li>';
                    }
                    ?>
                </ul>
            </nav>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS Bundle CDN -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
    // Handle the filter selection
    function applyFilters() {
        const itemType = document.getElementById('itemTypeFilter').value;
        const functionNote = document.getElementById('functionNoteFilter').value;
        const active = document.getElementById('activeFilter').value;
        window.location.href = `/crm/public/stock_item/view_stock_item.php?item_type=${itemType}&function_note=${functionNote}&active=${active}`;
    }

    // Reset filters
    document.getElementById('resetFilters').addEventListener('click', function () {
        window.location.href = '/crm/public/stock_item/view_stock_item.php';
    });

    document.getElementById('searchBar').addEventListener('input', function () {
        const searchValue = this.value.toLowerCase();
        const tableRows = document.querySelectorAll('#tableBody tr');
        let hasResults = false;

        tableRows.forEach(row => {
            const itemName = row.querySelector('.item-name');
            if (itemName) {
                const itemNameText = itemName.textContent.toLowerCase();
                if (itemNameText.includes(searchValue)) {
                    row.style.display = '';
                    hasResults = true;
                } else {
                    row.style.display = 'none';
                }
            }
        });

        // Show or hide the no results message
        document.getElementById('noResults').style.display = hasResults ? 'none' : 'block';
    });

    function sortTable(n) {
        var table, rows, switching, i, x, y, shouldSwitch, dir, switchcount = 0;
        table = document.querySelector("table");
        switching = true;
        dir = "asc";
        while (switching) {
            switching = false;
            rows = table.rows;
            for (i = 1; i < (rows.length - 1); i++) {
                shouldSwitch = false;
                x = rows[i].getElementsByTagName("TD")[n];
                y = rows[i + 1].getElementsByTagName("TD")[n];
                if (dir == "asc") {
                    if (x.innerHTML.toLowerCase() > y.innerHTML.toLowerCase()) {
                        shouldSwitch = true;
                        break;
                    }
                } else if (dir == "desc") {
                    if (x.innerHTML.toLowerCase() < y.innerHTML.toLowerCase()) {
                        shouldSwitch = true;
                        break;
                    }
                }
            }
            if (shouldSwitch) {
                rows[i].parentNode.insertBefore(rows[i + 1], rows[i]);
                switching = true;
                switchcount++;
            } else {
                if (switchcount == 0 && dir == "asc") {
                    dir = "desc";
                    switching = true;
                }
            }
        }
    }

    function toggleFunctionDetails(itemCodeId) {
        const detailsRow = document.getElementById(`function-${itemCodeId}`);
        if (detailsRow.style.display === "none" || detailsRow.style.display === "") {
            detailsRow.style.display = "table-cell";
        } else {
            detailsRow.style.display = "none";
        }
    }
</script>
</body>
</html>

