<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');


// Function to check if a table exists
function tableExists($pdo, $table) {
    try {
        $result = $pdo->query("SELECT 1 FROM $table LIMIT 1");
    } catch (Exception $e) {
        return FALSE;
    }
    return $result !== FALSE;
}

// Check if renewals table exists, if not, create it
if (!tableExists($pdo, 'renewals')) {
    $sql = "CREATE TABLE renewals (
        renewal_id INT AUTO_INCREMENT PRIMARY KEY,
        subscription_id INT,
        invoice_number VARCHAR(50),
        invoice_date DATE,
        start_date DATE,
        end_date DATE,
        amount DECIMAL(10, 2),
        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        FOREIGN KEY (subscription_id) REFERENCES subscriptions(subscription_id)
    )";
    $pdo->exec($sql);
}

// Get the subscription_id from the query parameter
if (isset($_GET['id'])) {
    $subscription_id = $_GET['id'];

    // Fetch current subscription data
    $sql = "SELECT * FROM subscriptions WHERE subscription_id = :subscription_id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':subscription_id', $subscription_id, PDO::PARAM_INT);
    $stmt->execute();
    $subscription = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$subscription) {
        echo "<script>alert('Subscription not found.'); window.location.href = 'view_subscription.php';</script>";
        exit();
    }
} else {
    echo "<script>alert('No subscription selected.'); window.location.href = 'view_subscription.php';</script>";
    exit();
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $invoice_number = $_POST['invoice_number'];
    $invoice_date = $_POST['invoice_date'];

    // Calculate new start and end dates
    $current_end_date = new DateTime($subscription['end_date']);
    $new_start_date = $current_end_date->modify('+1 day')->format('Y-m-d');
    $new_end_date = (new DateTime($new_start_date))->modify('+1 year -1 day')->format('Y-m-d');

    // Start a transaction
    $pdo->beginTransaction();

    try {
        // Insert a new subscription record
        $insert_subscription_sql = "INSERT INTO subscriptions (
            debtor_code, item_code, start_date, end_date, amount, others, duration
        ) VALUES (
            :debtor_code, :item_code, :start_date, :end_date, :amount, :others, :duration
        )";
        
        $stmt = $pdo->prepare($insert_subscription_sql);
        $stmt->bindParam(':debtor_code', $subscription['debtor_code']);
        $stmt->bindParam(':item_code', $subscription['item_code']);
        $stmt->bindParam(':start_date', $new_start_date);
        $stmt->bindParam(':end_date', $new_end_date);
        $stmt->bindParam(':amount', $subscription['amount']);
        $stmt->bindParam(':others', $subscription['others']);
        $stmt->bindParam(':duration', $subscription['duration']); // Copy duration to new subscription
        $stmt->execute();

        $new_subscription_id = $pdo->lastInsertId();

        // Insert a record into the renewals table for tracking
        $insert_renewal_sql = "INSERT INTO renewals (subscription_id, invoice_number, invoice_date, start_date, end_date, amount)
                               VALUES (:subscription_id, :invoice_number, :invoice_date, :start_date, :end_date, :amount)";
        $renewal_stmt = $pdo->prepare($insert_renewal_sql);
        $renewal_stmt->bindParam(':subscription_id', $subscription_id, PDO::PARAM_INT); // Use the old subscription_id
        $renewal_stmt->bindParam(':invoice_number', $invoice_number);
        $renewal_stmt->bindParam(':invoice_date', $invoice_date);
        $renewal_stmt->bindParam(':start_date', $new_start_date);
        $renewal_stmt->bindParam(':end_date', $new_end_date);
        $renewal_stmt->bindParam(':amount', $subscription['amount']);
        $renewal_stmt->execute();

        // Commit the transaction
        $pdo->commit();

        // Redirect to view_subscription.php with the new subscription_id
        echo "<script>alert('Subscription renewed successfully!'); window.location.href = 'view_subscription.php?id=" . $new_subscription_id . "';</script>";
        exit();
    } catch (Exception $e) {
        // An error occurred; rollback the transaction
        $pdo->rollBack();
        echo "<script>alert('Failed to renew subscription: " . htmlspecialchars($e->getMessage()) . "');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Renew Subscription</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h2 class="mb-0">Renew Subscription</h2>
            </div>
            <div class="card-body">
                <form action="renew_subscription.php?id=<?= $subscription_id; ?>" method="POST">
                    <div class="mb-3">
                        <label for="invoice_number" class="form-label">New Invoice Number</label>
                        <input type="text" id="invoice_number" name="invoice_number" class="form-control" required>
                    </div>
                    <div class="mb-3">
                        <label for="invoice_date" class="form-label">New Invoice Date</label>
                        <input type="date" id="invoice_date" name="invoice_date" class="form-control" required>
                    </div>
                    <button type="submit" class="btn btn-success">Renew</button>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>