<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');


// Get the current date and future date range
$current_date = new DateTime();
$future_30_days = (new DateTime())->modify('+30 days');
$past_150_days = (new DateTime())->modify('-150 days'); // 180 days total range

// Modified SQL to include invoice_number check from renewals table and join with item_code table
$sql = "SELECT s.subscription_id, s.duration, s.end_date, 
               i.item_name, c.company_name
        FROM subscriptions s
        LEFT JOIN company_info c ON s.debtor_code = c.debtor_code
        LEFT JOIN renewals r ON s.subscription_id = r.subscription_id
        LEFT JOIN item_code i ON s.item_code = i.item_code
        WHERE s.end_date BETWEEN :past_date AND :future_date
        AND (r.invoice_number IS NULL OR r.invoice_number = '')
        GROUP BY s.subscription_id
        ORDER BY s.end_date DESC";

$stmt = $pdo->prepare($sql);
$stmt->execute([
    ':past_date' => $past_150_days->format('Y-m-d'),
    ':future_date' => $future_30_days->format('Y-m-d')
]);
$subscriptions = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Pagination settings
$items_per_page = 5;
$total_items = count($subscriptions);
$total_pages = ceil($total_items / $items_per_page);

// Get the current page from the URL, default to 1
$current_page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$current_page = max(1, min($current_page, $total_pages));

// Calculate the offset
$offset = ($current_page - 1) * $items_per_page;

// Get the current page's data
$subscriptions_page = array_slice($subscriptions, $offset, $items_per_page);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Pending Invoice Subscriptions</title>
    <!-- Add Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-9ndCyUaIbzAi2FUVXJi0CjmCapSmO7SnpJef0486qhLnuZ2cdeRhO02iuK6FUUVM" crossorigin="anonymous">
    <style>
        .hidden {
            display: none;
        }
        .end-date-future {
            background-color: #d4edda;  /* Light green for future expiring */
        }
        .end-date-recent {
            background-color: #fff3cd;  /* Light yellow for recently expired */
        }
        .end-date-old {
            background-color: #f8d7da;  /* Light red for old expired */
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <h2 class="mb-4">Pending Invoice Subscriptions (Next 30 Days and Past 150 Days)</h2>
        <div class="mb-3">
            <span class="badge bg-success">Future Expiring</span>
            <span class="badge bg-warning text-dark">Recently Expired</span>
            <span class="badge bg-danger">Alerady Expired</span>
        </div>
        <table class="table table-bordered">
            <thead class="thead-dark">
                <tr>
                    <th>Company Name</th>
                    <th>Duration</th>
                    <th>End Date</th>
                    <th>Item Name</th>
                    <th>Status</th>
                    <th>Action</th>
                </tr>
            </thead>
            <tbody>
                <?php if (!empty($subscriptions_page)): ?>
                    <?php foreach ($subscriptions_page as $row): ?>
                        <?php
                        $end_date = new DateTime($row['end_date']);
                        $days_until_expiry = $current_date->diff($end_date)->format('%r%a');
                        
                        // Determine row class and status based on expiry
                        if ($days_until_expiry > 0) {
                            $row_class = 'end-date-future';
                            $status = "Expires in $days_until_expiry days";
                        } elseif ($days_until_expiry >= -30) {
                            $row_class = 'end-date-recent';
                            $status = "Expired " . abs($days_until_expiry) . " days ago";
                        } else {
                            $row_class = 'end-date-old';
                            $status = "Expired " . abs($days_until_expiry) . " days ago";
                        }
                        ?>
                        <tr class="<?= $row_class ?>">
                            <td><?= htmlspecialchars($row['company_name']); ?></td>
                            <td><?= htmlspecialchars($row['duration']) . ' Month'; ?></td>
                            <td><?= htmlspecialchars($row['end_date']); ?></td>
                            <td><?= htmlspecialchars($row['item_name']); ?></td>
                            <td><?= $status; ?></td>
                            <td>
                                <a href="view_subscription_details.php?id=<?= $row['subscription_id']; ?>" 
                                   class="btn btn-info btn-sm">View</a>
                                <?php
                                // Show different buttons based on expiry status
                                if ($days_until_expiry > -60) {  // Within 60 days of expiry (before or after)
                                    echo '<a href="renew_subscription.php?id=' . $row['subscription_id'] . '" 
                                         class="btn btn-warning btn-sm ml-1">Renew</a>';
                                } elseif ($days_until_expiry < -60) {  // More than 60 days expired
                                    echo '<a href="add_subscription.php?id=' . $row['subscription_id'] . '" 
                                         class="btn btn-success btn-sm ml-1">New</a>';
                                }
                                ?>
                                <a href="create_quotation.php?id=<?= $row['subscription_id']; ?>" 
                                   class="btn btn-primary btn-sm ml-1">Add Quotation</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="6" class="text-center">No pending invoice subscriptions found in the specified date range</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>

        <!-- Pagination links -->
        <?php if ($total_pages > 1): ?>
        <nav aria-label="Page navigation">
            <ul class="pagination justify-content-center">
                <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                    <li class="page-item <?= $i == $current_page ? 'active' : ''; ?>">
                        <a class="page-link" href="?page=<?= $i; ?>"><?= $i; ?></a>
                    </li>
                <?php endfor; ?>
            </ul>
        </nav>
        <?php endif; ?>
    </div>

    <!-- Add Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js" integrity="sha384-geWF76RCwLtnZ8qwWowPQNguL3RmwHVBC9FhGdlKrxdiJJigb/j/68SIy3Te4Bkz" crossorigin="anonymous"></script>
</body>
</html>